# iremitter-app

## getting started

This project is setup with [yarn](https://yarnpkg.com/)

### Environment Variables

You need the following variables defined in `.env` (Refer to `example.env` for reference):

- REACT_APP_MAPTILER_API_KEY
- REACT_APP_API_URL
- REACT_APP_VERSION

##### REACT_APP_MAPTILER_API_KEY

Before running this application you need to sign up with Map Tiler to be issued an API key.
This key is currently stored in the `.env` file with the variable name `REACT_APP_MAPTILER_API_KEY`.

### Install

> Note: If you do not have yarn installed run `npm i -g yarn` or `corepack enable` for Node.js >= 16.10

`yarn`

### Run

`yarn start`

### Build

Builds the app for production to the `build` folder.\
It correctly bundles React in production mode and optimizes the build for the best performance.

The build is minified and the filenames include the hashes.\
Your app is ready to be deployed!

See the section about [deployment](https://facebook.github.io/create-react-app/docs/deployment) for more information.

## To run the /ping route

Open the Docker Desktop GUI

Open the terminal

Move to the current working directory that the project is in. Run the following commands

`docker pull stoplight/prism`

`docker run --rm -v ${PWD}:/tmp -p 4010:4010 stoplight/prism mock -h 0.0.0.0 -d /tmp/public/resources/api/openapi.yml`

> Note: on linux system you may need to change to $(pwd) to get the current path

The container should show up as running on the docker desktop GUI. Using the command `docker ps` in the Windows Terminal shows the info about all current containers running.

Open a new browser with `http://localhost:4010/ping` will direct you to the RapidDoc page with your local server showing.

# QA/QC

Used for various QA/QC tests

##### Table of Contents

- [Setup](#setup)
- [Usage](#usage)
  - [Authentication](#auth)
  - [Run all tests](#all-tests)

## Setup

The tests require some NPM dependencies to run. They can be installed with one (goto the qaqc folder)
command:
npm install

### Run postman collections on command line using newman cli

To run the json files, the following dependencies are needed for the command line runner to work:

1. node (the Node.js programming language) version 8 or 10
2. npm (the NodeJS package manager) which typically gets installed with node
3. newman (the postman collection command line runner)

command:

> npm install -g newman

## Usage

###### All the test codes that are related to IREMITTER is placed within the qaqc folder. Details of the codes are as given below

**validation.json**

**_/ping_**(route)

1. Check Status Code
2. Check Body
3. Check Response Time
4. Check Content-Type

## auth

Currently test/codes does not require authentication.

## all-tests

#### Syntax to run the postman collections on command line

the below mentioned command will generate the normal run report of the postman collection

> newman run \<filename\>.json

The template to run the customised html report is placed inside the folder name templates. Using the below command we can generate the customized report.

> newman run \<filename\>.json -e ../env/\<env\>.json --reporters html --reporter-html-template complete filepath\<filename\>.hbs --reporter-html-export my_report.html my.collection.postman.json

using this command, we can run the collection on the desired test environment.

> newman run \<filename\>.json -e ../env/\<env\>.json

for more commands refer [Reference](https://learning.postman.com/docs/running-collections/using-newman-cli/command-line-integration-with-newman/)

## Tutorial

Test

#### This commands to run the newman on command line

the below mentioned command will run different stages like: sit,stg and prd.

1. qaqc --> validation.json(dev) :

   > newman run validation.json -e ../env/dev.json

2. qaqc --> validation.json(stg) :

   > newman run validation.json -e ../env/stg.json

3. qaqc --> validation.json(prd) :
   > newman run validation.json -e ../env/prd.json

# IR-Emitter QA/QC

Used for various QA/QC tests

##### Table of Contents

- [Setup](#setup)
- [Usage](#usage)
  - [Authentication](#auth)
  - [Run all tests](#all-tests)

## Setup

The tests require some NPM dependencies to run. They can be installed with one
command:

    npm install

### Run postman collections on command line using newman cli

To run the json files, the following dependencies are needed for the command line runner to work:

1. node (the Node.js programming language) version 8 or 10
2. npm (the NodeJS package manager) which typically gets installed with node
3. newman (the postman collection command line runner)

command:

> npm install -g newman

## Usage

There are one folders named **iremitter**.

###### All the test codes that are related to IREMMITTER is placed within the iremitter folder. Details of the codes are as given below

**validation.json**

1. Check iremiter UI-URL
2. Check iremiter API-URL
3. Check Deep Response
4. Check schema validation

## auth

Currently test/codes does not require authentication.

## all-tests

#### Syntax to run the postman collections on command line

the below mentioned command will generate the normal run report of the postman collection

> newman run \<filename\>.json

The template to run the customised html report is placed inside the folder name templates. Using the below command we can generate the customized report.

> newman run \<filename\>.json -e ../env/\<env\>.json --reporters html --reporter-html-template complete filepath\<filename\>.hbs --reporter-html-export my_report.html my.collection.postman.json

using this command, we can run the collection on the desired test environment.

> newman run \<filename\>.json -e ../env/\<env\>.json

for more commands refer [Reference](https://learning.postman.com/docs/running-collections/using-newman-cli/command-line-integration-with-newman/)

## Tutorial

Test

#### This commands to run the newman on command line

the below mentioned command will run different stages like: sit,stg and prd.

1. iremitter --> validation.json(sit) :
   > newman run validation.json -e ../env/sit.json
