

CREATE EXTENSION IF NOT EXISTS "uuid-ossp";
CREATE EXTENSION IF NOT EXISTS postgis;

CREATE TABLE "catalog_2020" ( 
    "catalog_id" UUid DEFAULT uuid_generate_v4() NOT NULL,
    "index" integer,
    "id" integer,
    "month" Text,
    "rh" double precision,
    "area" double precision,
    "areacorr" double precision,
    "rhcorr" double precision,
    "rhht" double precision,
    "bcm" double precision,
    "t_min" integer,
    "t_mean" real,
    "t_max" integer,
    "ellipticity" real,
    "pct" double precision,
    "geom" geometry(POINT),
    "nobs" integer,
    "ndtct" integer,
    "npass" integer,
    "lat_full20" double precision,
    "lon_full20" double precision,
    "id2019" integer,
    "id2018" integer,
    "id2017" integer,
    "id2016" integer,
    "id2015" integer,
    "id2020prel" integer,
    "iso" VARCHAR,
    "type" VARCHAR,
    "lon" double precision,
    "lat" double precision,
    "created_dt" Timestamp Without Time Zone DEFAULT now() NOT NULL,
    "modified_dt" Timestamp Without Time Zone DEFAULT now() NOT NULL,
    PRIMARY KEY ( "catalog_id" ),
    UNIQUE ("id")
);

CREATE TABLE "catalog_multiyear" ( 
    "catalog_multiyear_id" UUid DEFAULT uuid_generate_v4() NOT NULL,
    "index" integer,
    "id" text,
    "geom" geometry(POINT),
    "geometry" text,
    "area" real,
    "dist_std" double precision,
    "cov1" double precision,
    "N_dtct" integer,
    "N_dates" integer,
    "T_mean" double precision,
    "T_std" double precision,
    "time_flag" integer,
    "ID2015" integer,
    "ID2016" integer,
    "ID2017" integer,
    "ID2018" integer,
    "ID2019" integer,
    "ID2020" integer,
    "ID2021" integer,
    "COUNTRY" VARCHAR(100),
    "NCEI_ISO" text,
    "type_old" text,
    "type_fixed" text,
    "type" text,
    "category" text,
    "Plant ID" text,
    "Plant name (English)" text,
    "Volcano Number" double precision,
    "Volcano Name" text,
    "Activity Evidence" text,
    "Last Known Eruption" text,
    "Mine IDs" text,
    "Mine Name" text,
    "Object-Field_name" text,
    "lon" double precision,
    "lat" double precision,
    "created_dt" Timestamp Without Time Zone DEFAULT now() NOT NULL,
    "modified_dt" Timestamp Without Time Zone DEFAULT now() NOT NULL,
    PRIMARY KEY ( "catalog_multiyear_id" ),
    UNIQUE ("id")
);

CREATE TABLE "catalog_multiyear_temp" ( 
    "index" integer,
    "geometry" text,
    PRIMARY KEY ( "index" ),
    UNIQUE ("index")
);

CREATE TABLE "history" (
    "id" serial,
    "created_dt" Timestamp WITH Time ZONE DEFAULT now(),
    "schema_name" text,
    "table_name" text,
    "operation" text,
    "key_id" UUid,
    "new_val" jsonb,
    "old_val" jsonb,
    "modified_by" text
);

-- ==== INDEXES =====

-- CREATE INDEX IF NOT EXISTS idx_pick_list_name ON pick_list(type);

-- ====================================VIEWS================================
