require('dotenv').config();
const express = require('express');
const path = require('path');
const cors = require('cors');
const fs = require('fs');
const openapi = require('express-openapi');
const db = require('./utils/db');

db.authenticate()
  .then(() => console.log(`Database Connected: ${process.env.POSTGRES_HOST}`))
  .catch((err) => console.log('Error Connecting to DB', err));

const app = express();
app.use(express.json());
app.use(cors());

switch (process.env.ENV) {
  case 'development':
    app.use('/', express.static(path.resolve(__dirname, '../../build')));
    app.use('/dashboard', express.static(path.resolve(__dirname, '../../build')));
    app.use('/backgrounds', express.static(path.resolve(__dirname, '../../build')));
    app.use('/layers', express.static(path.resolve(__dirname, '../../build')));
    break;
  default:
    app.use('/', express.static(path.resolve(__dirname, 'public')));
    app.use('/dashboard', express.static(path.resolve(__dirname, 'public')));
    app.use('/backgrounds', express.static(path.resolve(__dirname, 'public')));
    app.use('/layers', express.static(path.resolve(__dirname, 'public')));
    break;
}

// app.all('*', (req, res, next) => {
//   console.log(req);
//   next();
// });

openapi.initialize({
  apiDoc: fs.readFileSync(path.resolve(__dirname, 'resources/openapi.yml'), 'utf8'),
  app,
  paths: path.resolve(__dirname, 'routes')
});

app.listen(8000, () => {
  console.log('App listening on port 8000');
});
