const db = require('../utils/db');
const { Sequelize } = require('sequelize');

const CatalogMultiyear = db.define(
  'catalog_multiyear',
  {
    catalog_multiyear_id: {
      type: Sequelize.UUID,
      allowNull: false,
      defaultValue: Sequelize.UUIDV4,
      primaryKey: true
    },
    index: {
      type: Sequelize.INTEGER,
      allowNull: true
    },
    id: {
      type: Sequelize.INTEGER,
      allowNull: true,
      unique: 'catalog_multiyear_id_key'
    },
    geometry: {
      type: Sequelize.GEOMETRY('POINT', 0),
      allowNull: true
    },
    area: {
      type: Sequelize.REAL,
      allowNull: true
    },
    dist_std: {
      type: Sequelize.DOUBLE,
      allowNull: true
    },
    cov1: {
      type: Sequelize.DOUBLE,
      allowNull: true
    },
    N_dtct: {
      type: Sequelize.INTEGER,
      allowNull: true
    },
    N_dates: {
      type: Sequelize.INTEGER,
      allowNull: true
    },
    T_mean: {
      type: Sequelize.DOUBLE,
      allowNull: true
    },
    T_std: {
      type: Sequelize.DOUBLE,
      allowNull: true
    },
    time_flag: {
      type: Sequelize.BOOLEAN,
      allowNull: true
    },
    ID2015: {
      type: Sequelize.INTEGER,
      allowNull: true
    },
    ID2016: {
      type: Sequelize.INTEGER,
      allowNull: true
    },
    ID2017: {
      type: Sequelize.INTEGER,
      allowNull: true
    },
    ID2018: {
      type: Sequelize.INTEGER,
      allowNull: true
    },
    ID2019: {
      type: Sequelize.INTEGER,
      allowNull: true
    },
    ID2020: {
      type: Sequelize.INTEGER,
      allowNull: true
    },
    ID2021: {
      type: Sequelize.INTEGER,
      allowNull: true
    },
    COUNTRY: {
      type: Sequelize.STRING(100),
      allowNull: true
    },
    NCEI_ISO: {
      type: Sequelize.STRING(5),
      allowNull: true
    },
    type_old: {
      type: Sequelize.STRING,
      allowNull: true
    },
    type_fixed: {
      type: Sequelize.STRING,
      allowNull: true
    },
    type: {
      type: Sequelize.STRING,
      allowNull: true
    },
    category: {
      type: Sequelize.STRING,
      allowNull: true
    },
    'Plant ID': {
      type: Sequelize.STRING,
      allowNull: true
    },
    'Plant name (English)': {
      type: Sequelize.STRING,
      allowNull: true
    },
    'Volcano Number': {
      type: Sequelize.INTEGER,
      allowNull: true
    },
    'Volcano Name': {
      type: Sequelize.STRING,
      allowNull: true
    },
    'Activity Evidence': {
      type: Sequelize.TEXT,
      allowNull: true
    },
    'Last Known Eruption': {
      type: Sequelize.TEXT,
      allowNull: true
    },
    'Mine IDs': {
      type: Sequelize.TEXT,
      allowNull: true
    },
    'Mine Name': {
      type: Sequelize.TEXT,
      allowNull: true
    },
    'Object-Field_name': {
      type: Sequelize.TEXT,
      allowNull: true
    },
    lon: {
      type: Sequelize.DOUBLE,
      allowNull: true
    },
    lat: {
      type: Sequelize.DOUBLE,
      allowNull: true
    },
    created_dt: {
      type: Sequelize.DATE,
      allowNull: false,
      defaultValue: Sequelize.Sequelize.fn('now')
    },
    modified_dt: {
      type: Sequelize.DATE,
      allowNull: false,
      defaultValue: Sequelize.Sequelize.fn('now')
    }
  },
  {
    tableName: 'catalog_multiyear',
    schema: 'public',
    timestamps: false,
    indexes: [
      {
        name: 'catalog_multiyear_id_key',
        unique: true,
        fields: [
          {
            name: 'id'
          }
        ]
      },
      {
        name: 'catalog_multiyear_pkey',
        unique: true,
        fields: [
          {
            name: 'catalog_multiyear_id'
          }
        ]
      }
    ]
  }
);

module.exports = CatalogMultiyear;
