const db = require('../../../utils/db');

const orderByValue = ['cnt', 'fieldname'];


module.exports = {
    get: async (req, res) => {
        const { orderBy, orderDir } = req.query;
        const { limit } = req.query;
        const { tableName } = req.params;
        let { fieldName } = req.params;
        let orderByFlag = false;
        let orderByDirectionFlag = false;
        // fix for sequelize field uppercase issue
        if (['country'].includes(fieldName)) {
            fieldName = `"${fieldName.toUpperCase()}"`;
        }
        if (orderBy && orderByValue.includes(orderBy)) {
            orderByFlag = true;
        }
        if (orderDir && (orderDir.toLowerCase() === 'asc' || orderDir.toLowerCase() === 'desc')) {
            orderByDirectionFlag = true;
        }
        let { filter } = req.query;

        let where = '';
        const wherOrderBy = orderByFlag ? `ORDER BY ${orderBy}` : `ORDER BY ${fieldName}`;
        const whereOrderDir = orderByDirectionFlag ? `${orderDir}` : 'ASC';

        try {
            JSON.parse(filter);
        } catch (err) {
            filter = '';
        }
        where =
      filter === '' ?
          'WHERE 1=1' :
          `WHERE ST_Intersects(st_setsrid(geom, 4326), st_setsrid(ST_GeomFromGeoJSON('${filter}'), 4326))`;

        const tableList = ['catalog_multiyear', 'catalog_2020'];
        if (!tableList.includes(tableName)) {
            res.status(400).json({
                message: 'Not a valid tableName',
                success: false
            });
        } else {
            let SQL = `SELECT ${fieldName} as fieldname, count(1) as cnt FROM ${tableName} ${where} GROUP BY ${fieldName} ${wherOrderBy} ${whereOrderDir}`;

            // if (limit) {
            //     SQL += ` LIMIT ${limit}`;
            // }
            try {
                // console.log(SQL);
                let results = await db.query(SQL, {
                    type: db.QueryTypes.SELECT
                });

                // TODO This is a patch to sort everything desc and convert the cnt to integer
                results = results.map((item) => {
                    item.cnt = parseInt(item.cnt, 10);
                    return item;
                });
                results.sort((a, b) => b.cnt - a.cnt);
                if (limit) {
                    results = results.slice(0, limit);
                }
                res.status(200).json({
                    data: results,
                    raw: true,
                    success: true
                });
            } catch (err) {
                console.log('Error: ', err);
                res.status(500).json({
                    message: `Internal Server Error: ${err.message}`,
                    success: false
                });
            }
        }
    }
};