const { getAuthToken, isAllowed, isTileValid } = require('../../../../../utils/functions');
const db = require('../../../../../utils/db');

module.exports = {
  get: async (req, res) => {
    const { z, x, y } = req.params;
    let { filter } = req.query;
    const contourZoom = process.env.CONTOUR_ZOOM || 12;
    let where = '';
    let SQL = '';
    try {
      JSON.parse(filter);
    } catch (err) {
      filter = '';
    }
    where =
      filter === ''
        ? 'WHERE 1=1'
        : `WHERE ST_Intersects(st_setsrid(geom, 4326), st_setsrid(ST_GeomFromGeoJSON('${filter}'), 4326))`;
    if (
      !isTileValid({
        x,
        y,
        z
      })
    ) {
      res.status(400);
    }

    // AND geom && ST_TileEnvelope(${z}, ${x}, ${y}, margin => (64.0 / 4096))

    if (z >= contourZoom && isAllowed(getAuthToken(req))) {
      // id as cluster_id,
      // SELECT ST_AsMVTGeom(st_transform(st_setsrid(geom, 4326), 3857), ST_TileEnvelope(${z}, ${x}, ${y}), extent => 4096, buffer => 64) AS geom,
      // SELECT ST_AsMVTGeom(st_transform(ST_GeomFromText(geometry, 4326), 3857), ST_TileEnvelope(${z}, ${x}, ${y}), extent => 4096, buffer => 64) AS geom
      // mean_area as
      SQL = `
        WITH mvtgeom AS
        (
        SELECT ST_AsMVTGeom(st_transform(st_setsrid(geom, 4326), 3857), TileBBox(${z}, ${x}, ${y}), extent => 4096, buffer => 64) AS geom,
        mean_area as area, lat, lon, type, index as id, id as catalog_id,
        dist_std, cov1, time_flag, "COUNTRY", "NCEI_ISO" as iso, category,"T_mean" as t_mean, mean_rh as rh, mean_pct as pct
        FROM catalog_multiyear
        ${where}
        ),
        mvtgeomcontour AS
        (
        SELECT ST_AsMVTGeom(st_transform(st_setsrid(flares_multiyear.fl_geom, 4326), 3857), TileBBox(${z}, ${x}, ${y}), extent => 4096, buffer => 64) AS geom
        FROM catalog_multiyear LEFT OUTER JOIN flares_multiyear ON flares_multiyear.id = catalog_multiyear.id
        ${where}
        )
        SELECT ST_AsMVT(mvtgeom.*, 'vnf', 4096, 'geom') as mvt FROM mvtgeom
        UNION
        SELECT ST_AsMVT(mvtgeomcontour.*, 'contour') as mvt FROM mvtgeomcontour
        ;
    `;
    } else {
      // SELECT ST_AsMVTGeom(st_transform(st_setsrid(geom, 4326), 3857), ST_TileEnvelope(${z}, ${x}, ${y}), extent => 4096, buffer => 64) AS geom,
      // id as cluster_id,
      SQL = `
        WITH mvtgeom AS
        (
        SELECT ST_AsMVTGeom(st_transform(st_setsrid(geom, 4326), 3857), TileBBox(${z},${x},${y}), extent => 4096, buffer => 64) as geom,
        mean_area as area, lat, lon, type, index as id, id as catalog_id,
        dist_std, cov1, time_flag, "COUNTRY", "NCEI_ISO" as iso, category, "T_mean" as t_mean, mean_rh as rh, mean_pct as pct
        FROM catalog_multiyear
        ${where}
        )
        SELECT ST_AsMVT(mvtgeom.*, 'vnf') as mvt
        FROM mvtgeom;
      `;
    }
    try {
      // console.log(SQL);
      const tile = await db.query(SQL);
      const tilesLayer = tile[0];
      const buffers = [];
      tilesLayer.forEach((item) => {
        buffers.push(item.mvt);
      });
      const finalbuffer = Buffer.concat(buffers);
      res.setHeader('Content-Type', 'application/vnd.mapbox-vector-tile');
      if (finalbuffer.length === 0) {
        res.status(204);
      }
      res.send(finalbuffer);
    } catch (e) {
      console.log('Error:', e);
      res.status(404).send({
        error: e.toString()
      });
    }
  }
};
