const { getAuthToken, isAllowed, isTileValid } = require('../../../../../utils/functions');
const db = require('../../../../../utils/db');

module.exports = {
  get: async (req, res) => {
    const { z, x, y } = req.params;
    let { filter } = req.query;
    const contourZoom = process.env.CONTOUR_ZOOM || 12;
    let where = '';
    let SQL = '';
    const orderBy = ' ORDER BY rh desc';
    try {
      JSON.parse(filter);
    } catch (err) {
      filter = '';
    }
    where =
      filter === ''
        ? ''
        : `WHERE ST_Intersects(st_setsrid(geom, 4326),  st_setsrid(ST_GeomFromGeoJSON('${filter}'), 4326))`;
    if (
      !isTileValid({
        x,
        y,
        z
      })
    ) {
      res.status(400);
    }
    // const bbox = mercator.bbox(x, y, z, false);
    // SELECT ST_AsMVTGeom(st_transform(st_setsrid(geom, 4326), 3857), ST_TileEnvelope(${z}, ${x}, ${y}), extent => 4096, buffer => 64) AS geom, modified_dt,index,id,lat,created_dt,catalog_id,rh,area,areacorr,rhcorr,rhht,bcm,t_min,t_mean,t_max,ellipticity,pct,nobs,ndtct,npass,lat_full20,lon_full20,id2019,id2018,id2017,id2016,id2015,id2020prel,lon,month,type,iso
    // modified_dt,created_dt,catalog_id,
    if (z >= contourZoom && isAllowed(getAuthToken(req))) {
      SQL = `
          WITH mvtgeom AS
          (
            SELECT ST_AsMVTGeom(st_transform(st_setsrid(geom, 4326), 3857), TileBBox(${z}, ${x}, ${y}), extent => 4096, buffer => 64) AS geom,
            index,id,lat,rh,area,areacorr,rhcorr,rhht,bcm,t_min,t_mean,t_max,ellipticity,pct,nobs,ndtct,npass,lat_full20,lon_full20,id2019,id2018,id2017,id2016,id2015,id2020prel,lon,month,type,iso
            FROM catalog_2020
            ${where}
            ),
            mvtgeomcontour AS
            (
            SELECT ST_AsMVTGeom(st_transform(st_setsrid(flares_2020.fl_geom, 4326), 3857), TileBBox(${z}, ${x}, ${y}), extent => 4096, buffer => 64) AS geom
            FROM catalog_2020 LEFT OUTER JOIN flares_2020 ON flares_2020.id = catalog_2020.id
            ${where}
            )
            SELECT ST_AsMVT(mvtgeom.*, 'vnf', 4096, 'geom') as mvt
            FROM mvtgeom
            UNION
            SELECT ST_AsMVT(mvtgeomcontour.*, 'contour') as mvt FROM mvtgeomcontour
            ;
        `;
    } else {
      SQL = `
          WITH mvtgeom AS
          (
            SELECT ST_AsMVTGeom(st_transform(st_setsrid(geom, 4326), 3857), TileBBox(${z}, ${x}, ${y}), extent => 4096, buffer => 64) AS geom,
            index,id,lat,rh,area,areacorr,rhcorr,rhht,bcm,t_min,t_mean,t_max,ellipticity,pct,nobs,ndtct,npass,lat_full20,lon_full20,id2019,id2018,id2017,id2016,id2015,id2020prel,lon,month,type,iso
            FROM catalog_2020
            ${where} ${orderBy}
            )
            SELECT ST_AsMVT(mvtgeom.*, 'vnf') as mvt
            FROM mvtgeom;
        `;
    }
    try {
      // console.log(SQL);
      const tile = await db.query(SQL);
      const tilesLayer = tile[0];
      const buffers = [];
      tilesLayer.forEach((item) => {
        buffers.push(item.mvt);
      });
      const finalbuffer = Buffer.concat(buffers);
      res.setHeader('Content-Type', 'application/vnd.mapbox-vector-tile');
      if (finalbuffer.length === 0) {
        res.status(204);
      }
      res.send(finalbuffer);
    } catch (e) {
      console.log('Error: ', e);
      res.status(404).send({
        error: e.toString()
      });
    }
  }
};
