const { Parser } = require('json2csv');
// const fs = require('fs');
// const { getAuthToken, isAllowed } = require('../../../../utils/functions');
// const path = require('path');
const axios = require('axios');
const https = require('https');

const Catalog2020 = require('../../../../models/Catalog2020');
const MultiyearAnnual = require('../../../../models/MultiyearAnnual');
const MultiyearMonthly = require('../../../../models/MultiyearMonthly');

const seriesList = ['day', 'month', 'static', 'year'];

const types = {
  multiyear: 'multiyear_vnf',
  y2020: 'y2020'
};

async function getData(series, type, id) {
  let data;
  switch (type) {
    case types.multiyear:
      switch (series) {
        case 'month':
          data = await MultiyearMonthly.findAll({
            attributes: [
              ['month', 'index'],
              ['rh', 'RH'],
              ['t_mean', 'Temp_BB'],
              ['bcm', 'Flow_Rate']
            ],
            where: {
              id
            }
          });
          if (data?.length) {
            data = data.map((elem) => elem.dataValues);
          }
          break;
        case 'year':
          data = await MultiyearAnnual.findAll({
            attributes: [
              ['month', 'index'],
              ['rh', 'RH'],
              ['t_mean', 'Temp_BB'],
              ['bcm', 'Flow_Rate']
            ],
            where: {
              id
            }
          });
          if (data?.length) {
            data = data.map((elem) => elem.dataValues);
          }
          break;
        case 'day':
        default:
          data = await axios.get('https://mocki.io/v1/c987aca9-6544-47c8-b60f-40fd69fdbfc5');
          data = data.data;
          break;
      }
      break;
    case types.y2020:
    default:
      switch (series) {
        case 'month':
        case 'year':
          data = await Catalog2020.findAll({
            attributes: [
              ['month', 'index'],
              ['rh', 'RH'],
              ['t_mean', 'Temp_BB'],
              ['bcm', 'Flow_Rate']
            ],
            where: {
              id
            }
          });
          if (data?.length) {
            data = data.map((elem) => elem.dataValues);
          }
          break;
        case 'day':
        default:
          data = await axios.get('https://mocki.io/v1/341ca656-6ee7-42e3-ad35-2462ed713146');
          data = data.data;
          break;
      }
      break;
  }
  return data;
}

async function getDownloadData(series, type, id) {
  let data;
  switch (type) {
    case types.multiyear:
      switch (series) {
        case 'month':
        default:
          data = await MultiyearMonthly.findAll({
            where: {
              id
            }
          });
          if (data?.length) {
            data = data.map((elem) => elem.dataValues);
          }
          break;
        case 'year':
          data = await MultiyearAnnual.findAll({
            where: {
              id
            }
          });
          if (data?.length) {
            data = data.map((elem) => elem.dataValues);
          }
          break;
      }
      break;
    case types.y2020:
    default:
      switch (series) {
        case 'month':
        case 'year':
        default:
          data = await Catalog2020.findAll({
            where: {
              id
            }
          });
          if (data?.length) {
            data = data.map((elem) => elem.dataValues);
          }
          break;
      }
      break;
  }
  return data;
}

const getCsvDetails = (type, id) => {
  switch (type) {
    case types.y2020:
      return {
        filename: `flare_${id}_y2020_vnf_series.csv`,
        url: `https://eogdata.mines.edu/wwwdata/giree/vnf_profiles/profiles/flare_${id}_y2020_vnf_series.csv`
      };
    case types.multiyear:
    default:
      return {
        filename: `site_${id}_multiyear_vnf_series.csv`,
        url: `https://eogdata.mines.edu/wwwdata/giree/vnf_profiles/profiles_multiyear/site_${id}_multiyear_vnf_series.csv`
      };
  }
};

module.exports = {
  // eslint-disable-next-line consistent-return
  get: async (req, res) => {
    const { id, series, type } = req.params;
    const { format } = req.query;
    const typeList = [types.multiyear, types.y2020];
    let data;
    let methaneCount = 0;

    // if (!isAllowed(getAuthToken(req))) {
    //   return res.status(403).json({ message: 'Insufficient permissions' });
    // }

    if (!seriesList.includes(series)) {
      return res.status(400).json({ message: 'Invalid series type' });
    }

    if (!typeList.includes(type)) {
      return res.status(400).json({ message: 'Invalid type' });
    }

    if (format === 'csv') {
      try {
        const prefix = series === 'month' ? 'viirs' : 'multiyear';
        const filename = `flare_${id}_${prefix}_${series}_vnf_series.csv`;

        data = await getDownloadData(series, type, id);
        const json2csv = new Parser({});
        const csv = json2csv.parse(data);
        res.header('Content-Type', 'text/csv');
        res.attachment(filename);
        return res.send(csv);
      } catch (err) {
        console.log(err);
        res.status(500).send({
          error: err.toString()
        });
      }
    } else if (format === 'file') {
      const { filename, url } = getCsvDetails(type, id);
      res.header('Content-Disposition', `attachment; filename="${filename}"`);
      res.header('Content-Type', 'text/csv');
      https.get(url, (stream) => {
        stream.pipe(res);
      });
    } else {
      const output = {
        methane: [],
        rh: [],
        temperature: [],
        useMethane: true
      };

      try {
        let substrLimit = 0;
        switch (series) {
          case 'month':
            substrLimit = -8;
            break;
          case 'year':
            substrLimit = -4;
            break;
          case 'day':
          default:
            substrLimit = 0;
            break;
        }
        data = await getData(series, type, id);
        data.forEach((element) => {
          const key = element.index.substring(0, 16);
          const label = element.index.substr(substrLimit);
          output.temperature.push({
            label,
            x: key,
            y: element.Temp_BB
          });
          output.rh.push({
            label,
            x: key,
            y: element.RH
          });
          output.methane.push({
            label,
            x: key,
            y: element.Flow_Rate
          });
          if (element.Flow_Rate === 999999) {
            methaneCount += 1;
          }
          if (methaneCount > 5) {
            output.useMethane = false;
          }
        });
        output.averageTemparature = output.temperature
          ? output.temperature.reduce((p, c) => p + c.y, 0) / output.temperature.length
          : 0;
        res.status(200).json(output);
      } catch (err) {
        console.log(err);
        res.status(500).send({
          error: err.toString()
        });
      }
    }
  }
};
