const SequelizeAuto = require('sequelize-auto');
require('dotenv').config({ path: '../../../.env' });
const { connect } = require('../index');
const { skipTables } = require('./tables');

const getDb = (type = 'postgres') => {
    const map = {
        postgres: {
            dialect: 'postgres'
        }
    };
    return map[type];
};

function buildAutoOptions({ path = '../../models', skipTables = [], tables, db, lang = 'es6', ...rest }) {
    const autoOptions = {
        caseModel: 'p',
        directory: path,
        indentation: 4,
        lang,
        skipTables,
        spaces: true,
        tables
    };
    return { ...db, ...autoOptions, ...rest };
}

async function build(options, { sequelizeOptions }) {
    const { SequelizeAuto, sequelize } = options;
    const auto = new SequelizeAuto(sequelize, null, null, sequelizeOptions);
    return auto.run();
}

(async ({ skipTables }) => {
    const db = getDb('postgres');
    try {
        const sequelize = await connect(process.env);
        const sequelizeOptions = buildAutoOptions({
            caseFile: 'p',
            db,
            path: '../../models',
            skipTables,
            views: true
        });
        const { tables } = await build(
            {
                SequelizeAuto,
                sequelize
            },
            {
                sequelizeOptions
            }
        );
        console.log('\nModels are created for following tables...');
        const res = Object.keys(tables);
        console.log('\nTables:', res, '\nCount:', res.length);
        sequelize.close();
    } catch (err) {
        console.log(err);
    }
})({ skipTables });
