const jwt = require('jwt-decode');

function getAuthToken(req) {
  if (req?.headers?.authorization && req.headers.authorization.split(' ')[0] === 'Bearer') {
    return req.headers.authorization.split(' ')[1];
  }
  return null;
}

function isAllowed(token) {
  const roleGroupList = [
    '/external/paid_subscriber/vnf_nrt',
    '/external/paid_subscriber/vnf_ogci',
    '/external/paid_subscriber/vnf_interim',
    '/external/academic_access/vnf',
    '/eog_staff'
  ];
  try {
    const decodedData = jwt(token);
    return decodedData.group.some((g) => roleGroupList.includes(g));
  } catch (err) {
    return false;
  }
}

function isTileValid(tile) {
  const min = 0;
  const max = 2 ** tile.z - 1;
  return min <= tile.x <= max && min <= tile.y <= max;
}

function tileToEnvelope(tile) {
  // Width of world in EPSG:3857
  const worldMercMax = 20037508.3427892;
  const worldMercMin = -1 * worldMercMax;
  const worldMercSize = worldMercMax - worldMercMin;
  // Width in tiles
  const worldTileSize = 2 ** tile.z;
  // Tile width in EPSG:3857
  const tileMercSize = worldMercSize / worldTileSize;
  // Calculate geographic bounds from tile coordinates
  // XYZ tile coordinates are in "image space" so origin is top-left, not bottom right
  return {
    maxX: worldMercMin + tileMercSize * (tile.x + 1),
    minX: worldMercMin + tileMercSize * tile.x,
    maxY: worldMercMax - tileMercSize * tile.y,
    minY: worldMercMax - tileMercSize * (tile.y + 1)
  };
}

module.exports = {
  getAuthToken,
  isAllowed,
  isTileValid,
  tileToEnvelope
};
