import { getPolygonFeatures, removeDetectionsLayerIf, removePulseLayerIf } from 'utils/layerUtils';

const dotPointLayerConfig = {
  dot: {
    id: 'layer-with-pulsing-dot',
    type: 'symbol',
    source: 'dot-point',
    layout: {
      'icon-image': 'pulsing-dot'
    }
  },
  random: {
    id: 'random-layer-with-pulsing-dot',
    type: 'symbol',
    source: 'random-dot-point',
    layout: {
      'icon-image': 'random-pulsing-dot'
    }
  }
};

const addPulse = (map, lat, lon, pulsingDot, layerId, type = 'dot', draw = null) => {
  const dotPointSource = {
    type: 'geojson',
    data: {
      type: 'FeatureCollection',
      features: [
        {
          type: 'Feature',
          geometry: {
            type: 'Point',
            coordinates: [lon, lat]
          }
        }
      ]
    }
  };
  if (!map.hasImage(dotPointLayerConfig[type].layout['icon-image'])) {
    map.addImage(dotPointLayerConfig[type].layout['icon-image'], pulsingDot, { pixelRatio: 2 });
  }
  if (map.getSource(dotPointLayerConfig[type].source) === undefined) {
    map.addSource(dotPointLayerConfig[type].source, dotPointSource);
  }
  if (map.getLayer(dotPointLayerConfig[type].id) === undefined) {
    map.addLayer(dotPointLayerConfig[type], layerId);
    map.on('mouseenter', dotPointLayerConfig[type].id, () => {
      map.getCanvas().style.cursor = 'pointer';
    });
    map.on('mouseleave', dotPointLayerConfig[type].id, () => {
      map.getCanvas().style.cursor = '';
    });
    if (type === 'random') {
      map.on('click', dotPointLayerConfig.random.id, () => {
        const featureCollection = getPolygonFeatures(draw);
        if (featureCollection) {
          draw.set(featureCollection);
        } else {
          draw.deleteAll();
        }
        removeDetectionsLayerIf(map, type);
        removePulseLayerIf(map, type);
      });
    }
  }
};

export { dotPointLayerConfig, addPulse };
