import ReactDOM from 'react-dom';

import InfoTpl from 'ui-component/cards/InfoTpl';
import multiYearConfig from './viirsMultiYearConfig';
import { getActiveTypeFilters, getActiveCategoryFilters } from 'utils/filterUtils';
import {
  deleteExtraPolygons,
  getPolygonFeatures,
  handleMarker,
  updateVNFFilter,
  popup,
  generateLayerConfig,
  getStyle,
  emitterClickHandler
} from 'utils/layerUtils';

const viirsYear = {
  config: multiYearConfig,
  id: multiYearConfig.id,
  name: multiYearConfig.name,
  description: multiYearConfig.description,
  enabled: multiYearConfig.enabled,
  metadata: multiYearConfig.metadata,
  requiredAuthLevel: multiYearConfig.requiredAuthLevel,
  tooltipText: multiYearConfig.tooltipText,
  on: {
    load: (map, draw, callback, stateObj) => [
      () => {
        const { layerState, filterState } = stateObj;
        const { circleRadius, circleColor } = getStyle(layerState.style, multiYearConfig);
        if (map.getSource(multiYearConfig.id) === undefined) {
          map.addSource(multiYearConfig.id, multiYearConfig.layerSource);
        }
        if (map.getLayer(multiYearConfig.id) === undefined) {
          map.addLayer(
            generateLayerConfig(
              multiYearConfig.id,
              multiYearConfig.layerType,
              multiYearConfig.paint(circleRadius, circleColor),
              multiYearConfig.id,
              multiYearConfig.sourceLayer,
              multiYearConfig.metadata
            )
          );

          let countryFilter = null;
          const { selectedCountry } = filterState;
          if (filterState && selectedCountry && selectedCountry.alpha3) {
            countryFilter = ['==', 'iso', selectedCountry.alpha3];
          }

          let typeFilter = null;
          const activeTypeFilters = getActiveTypeFilters(filterState);
          if (activeTypeFilters.length) {
            typeFilter = ['in', 'type', ...activeTypeFilters];
          }

          let categoryFilter = null;
          const activeCategoryFilters = getActiveCategoryFilters(filterState);
          if (activeCategoryFilters.length) {
            categoryFilter = ['in', 'category', ...activeCategoryFilters];
          }

          const layersFilter = ['all'];
          if (countryFilter || typeFilter || categoryFilter) {
            if (countryFilter) {
              layersFilter.push(countryFilter);
            }
            if (typeFilter) {
              layersFilter.push(typeFilter);
            }
            if (categoryFilter) {
              layersFilter.push(categoryFilter);
            }
          }

          if (layersFilter.length > 1 && map.getLayer(multiYearConfig.id)) {
            map.setFilter(multiYearConfig.id, layersFilter);
          }
        }
        if (multiYearConfig.sublayers.length > 0) {
          multiYearConfig.sublayers.forEach((sublayer) => {
            if (map.getLayer(sublayer.id) === undefined) {
              map.addLayer(
                generateLayerConfig(
                  sublayer.id,
                  sublayer.layerType,
                  sublayer.paint(),
                  multiYearConfig.id,
                  sublayer.sourceLayer,
                  sublayer.metadata
                )
              );
            }
          });
        }
      }
    ],
    click: (map, draw, callback) => [
      multiYearConfig.id,
      (event) => emitterClickHandler(event, multiYearConfig, map, draw, callback)
    ],
    mouseenter: (map, draw, callback, stateObj) => [
      multiYearConfig.id,
      (event) => {
        const { properties } = event.features[0];
        const { lat, lon } = properties;
        const { id: layerId } = multiYearConfig;
        map.getCanvas().style.cursor = 'pointer';
        const coordinates = [lon, lat].slice();
        if (properties) {
          const placeHolder = document.createElement('div');
          ReactDOM.render(
            <InfoTpl
              properties={{ ...properties, layerId }}
              countries={stateObj.filterState.countries}
            />,
            placeHolder
          );
          popup.setDOMContent(placeHolder).setLngLat(coordinates).addTo(map);
        }
      }
    ],
    mouseleave: (map) => [
      multiYearConfig.id,
      () => {
        map.getCanvas().style.cursor = '';
        popup.remove();
      }
    ],
    'draw.create': (map, draw, callback, stateObj, dispatch, setSelectionToolCoordinates) => [
      (event) => {
        handleMarker(event, map, multiYearConfig, draw);
        const featureCollection = deleteExtraPolygons(draw);
        if (featureCollection) {
          updateVNFFilter(
            map,
            multiYearConfig.id,
            featureCollection,
            multiYearConfig.tileSource,
            dispatch,
            setSelectionToolCoordinates
          );
        }
      }
    ],
    'draw.update': (map, draw, callback, stateObj, dispatch, setSelectionToolCoordinates) => [
      () => {
        const featureCollection = getPolygonFeatures(draw);
        if (featureCollection) {
          updateVNFFilter(
            map,
            multiYearConfig.id,
            featureCollection,
            multiYearConfig.tileSource,
            dispatch,
            setSelectionToolCoordinates
          );
        } else {
          map.getSource(multiYearConfig.id).setTiles([multiYearConfig.tileSource]);
          dispatch(setSelectionToolCoordinates(null));
        }
      }
    ],
    'draw.delete': (map, draw, callback, stateObj, dispatch, setSelectionToolCoordinates) => [
      () => {
        map.getSource(multiYearConfig.id).setTiles([multiYearConfig.tileSource]);
        dispatch(setSelectionToolCoordinates(null));
      }
    ]
  }
};

export default viirsYear;
