import { useTheme } from '@mui/material/styles';
import { Badge, Box, Button, Tooltip } from '@mui/material';
import { IconFilter } from '@tabler/icons';

import { dispatch, useSelector } from 'store';
import { ContextEnum, setCurrentContext } from 'store/slices/dashboard';
import { getActiveCategoryFiltersCount, getActiveTypeFiltersCount } from 'utils/filterUtils';

const FilterToggle = () => {
  const theme = useTheme();
  const dashboardState = useSelector((state) => state.dashboard);
  const filtersState = useSelector((state) => state.filters);

  const handleToggle = () => {
    if (dashboardState.currentContext === ContextEnum.Filter) {
      dispatch(setCurrentContext(ContextEnum.Overview));
    } else {
      dispatch(setCurrentContext(ContextEnum.Filter));
    }
  };

  const color =
    dashboardState.currentContext === ContextEnum.Filter
      ? theme.palette.primary.light
      : theme.palette.primary.main;
  const background =
    dashboardState.currentContext === ContextEnum.Filter
      ? theme.palette.primary.main
      : theme.palette.primary.light;

  let activeFilterCount = getActiveTypeFiltersCount(filtersState);
  activeFilterCount += getActiveCategoryFiltersCount(filtersState);
  if (filtersState.selectedCountry) {
    activeFilterCount += 1;
  }

  return (
    <Tooltip title="Toggle map filters">
      <Box
        sx={{
          mr: 4,
          [theme.breakpoints.down('md')]: {
            ml: 1
          }
        }}
      >
        <Badge badgeContent={activeFilterCount} color="primary">
          <Button
            // variant="outlined"
            startIcon={<IconFilter />}
            onClick={handleToggle}
            color="inherit"
            sx={{
              background,
              color,
              transition: 'all .2s ease-in-out',
              '&[aria-controls="menu-list-grow"],&:hover': {
                background: theme.palette.primary.main,
                color: theme.palette.primary.light
              }
            }}
          >
            Filter
          </Button>
        </Badge>
      </Box>
    </Tooltip>
  );
};

export default FilterToggle;
