import { useTheme } from '@mui/material/styles';
import { Avatar, Box } from '@mui/material';

import LogoSection from './LogoSection';
import MainMenu from './MainMenu';
import FilterToggle from './FilterToggle';
import { useDispatch, useSelector } from 'store';
import { openDrawer } from 'store/slices/menu';

import { IconMenu2 } from '@tabler/icons';
import FeedbackModal from 'ui-component/modals/FeedbackModal';
import FeedbackButton from 'layout/MainLayout/Header/FeedbackButton';
import MapLegendModal from 'ui-component/modals/MapLegendModal';
import MapLegendButton from 'layout/MainLayout/Header/MapLegendButton';

const Header = () => {
  const theme = useTheme();
  const dispatch = useDispatch();
  const { drawerOpen } = useSelector((state) => state.menu);
  const mapState = useSelector((state) => state.map);
  const { map } = mapState;

  const handleToggleDrawaer = () => {
    dispatch(openDrawer(!drawerOpen));
    let count = 0;
    while (count < 400) {
      setTimeout(() => map?.resize(), count);
      count += 1;
    }
  };

  return (
    <>
      <Box
        sx={{
          width: 228,
          display: 'flex',
          [theme.breakpoints.down('md')]: {
            width: 'auto'
          }
        }}
      >
        <Avatar
          variant="rounded"
          sx={{
            ...theme.typography.commonAvatar,
            ...theme.typography.mediumAvatar,
            overflow: 'hidden',
            transition: 'all .2s ease-in-out',
            background:
              theme.palette.mode === 'dark'
                ? theme.palette.dark.main
                : theme.palette.secondary.light,
            color:
              theme.palette.mode === 'dark'
                ? theme.palette.secondary.main
                : theme.palette.secondary.dark,
            marginRight: '12px',
            '&:hover': {
              background:
                theme.palette.mode === 'dark'
                  ? theme.palette.secondary.main
                  : theme.palette.secondary.dark,
              color:
                theme.palette.mode === 'dark'
                  ? theme.palette.secondary.light
                  : theme.palette.secondary.light
            }
          }}
          onClick={handleToggleDrawaer}
          color="inherit"
        >
          <IconMenu2 stroke={1.5} size="20px" />
        </Avatar>
        <Box component="span" sx={{ display: { xs: 'none', md: 'block' }, flexGrow: 1 }}>
          <LogoSection />
        </Box>
      </Box>
      <Box sx={{ flexGrow: 1 }} />
      <FeedbackModal FeedbackButton={FeedbackButton} />
      <MapLegendModal MapLegendButton={MapLegendButton} />
      <FilterToggle />
      <MainMenu />
    </>
  );
};

export default Header;
