import PropTypes from 'prop-types';
import { memo, useMemo } from 'react';

import PerfectScrollbar from 'react-perfect-scrollbar';
import { useTheme } from '@mui/material/styles';
import { Box, Button, Drawer, Grid, Link, Stack, Typography, useMediaQuery } from '@mui/material';
import { IconExternalLink } from '@tabler/icons';

import Chip from 'ui-component/extended/Chip';
import MenuList from './MenuList';
import MenuCard from './MenuCard';
import LogoSection from '../Header/LogoSection';
import { openDrawer } from 'store/slices/menu';
import { useDispatch, useSelector } from 'store';
import { drawerWidth } from 'store/constant';

const Sidebar = ({ window }) => {
  const theme = useTheme();
  const matchUpMd = useMediaQuery(theme.breakpoints.up('md'));

  const dispatch = useDispatch();
  const { drawerOpen } = useSelector((state) => state.menu);

  const color = theme.palette.primary.main;
  const background = theme.palette.primary.light;

  const logo = useMemo(
    () => (
      <Box sx={{ display: { xs: 'block', md: 'none' } }}>
        <Box sx={{ display: 'flex', p: 2, mx: 'auto' }}>
          <LogoSection />
        </Box>
      </Box>
    ),
    []
  );

  const drawer = useMemo(
    () => (
      <PerfectScrollbar
        component="div"
        style={{
          height: !matchUpMd ? 'calc(100vh - 56px)' : 'calc(100vh - 88px)',
          paddingLeft: '16px',
          paddingRight: '16px'
        }}
      >
        <MenuList />
        <MenuCard />
        <Stack direction="column" justifyContent="center" sx={{ mb: 2 }}>
          <Grid item xs={12}>
            <Grid container spacing={1}>
              <Grid item xs={8}>
                <Link
                  href="https://payneinstitute.mines.edu/eog/viirs-nightfire-vnf/"
                  target="_blank"
                  rel="noreferrer"
                  underline="none"
                  sx={{
                    background,
                    color,
                    transition: 'all .2s ease-in-out',
                    '&[aria-controls="menu-list-grow"],&:hover': {
                      background: theme.palette.primary.main,
                      color: theme.palette.primary.light
                    }
                  }}
                >
                  <Button
                    startIcon={<IconExternalLink />}
                    sx={{
                      background,
                      color,
                      transition: 'all .2s ease-in-out',
                      '&[aria-controls="menu-list-grow"],&:hover': {
                        background: theme.palette.primary.main,
                        color: theme.palette.primary.light
                      }
                    }}
                  >
                    <Typography
                      ariant="h5"
                      sx={{
                        background,
                        color,
                        transition: 'all .2s ease-in-out',
                        '&[aria-controls="menu-list-grow"],&:hover': {
                          background: theme.palette.primary.main,
                          color: theme.palette.primary.light
                        }
                      }}
                    >
                      Citation
                    </Typography>
                  </Button>
                </Link>
              </Grid>
              <Grid item xs={8}>
                <Link
                  href="https://eogdata.mines.edu/products/vnf/#data_format"
                  target="_blank"
                  rel="noreferrer"
                  underline="none"
                  sx={{
                    background,
                    color,
                    transition: 'all .2s ease-in-out',
                    '&[aria-controls="menu-list-grow"],&:hover': {
                      background: theme.palette.primary.main,
                      color: theme.palette.primary.light
                    }
                  }}
                >
                  <Button
                    startIcon={<IconExternalLink />}
                    sx={{
                      background,
                      color,
                      transition: 'all .2s ease-in-out',
                      '&[aria-controls="menu-list-grow"],&:hover': {
                        background: theme.palette.primary.main,
                        color: theme.palette.primary.light
                      }
                    }}
                  >
                    <Typography
                      ariant="h5"
                      sx={{
                        background,
                        color,
                        transition: 'all .2s ease-in-out',
                        '&[aria-controls="menu-list-grow"],&:hover': {
                          background: theme.palette.primary.main,
                          color: theme.palette.primary.light
                        }
                      }}
                    >
                      Documentation
                    </Typography>
                  </Button>
                </Link>
              </Grid>
            </Grid>
          </Grid>
        </Stack>
        <Stack direction="row" justifyContent="center" sx={{ mb: 2 }}>
          <Chip label={process.env.REACT_APP_VERSION} disabled chipcolor="secondary" size="small" />
        </Stack>
      </PerfectScrollbar>
    ),
    // eslint-disable-next-line react-hooks/exhaustive-deps
    [matchUpMd]
  );

  const container = window !== undefined ? () => window.document.body : undefined;

  return (
    <Box
      component="nav"
      sx={{ flexShrink: { md: 0 }, width: matchUpMd ? drawerWidth : 'auto' }}
      aria-label="mailbox folders"
    >
      <Drawer
        container={container}
        variant={matchUpMd ? 'persistent' : 'temporary'}
        anchor="left"
        open={drawerOpen}
        onClose={() => dispatch(openDrawer(!drawerOpen))}
        sx={{
          '& .MuiDrawer-paper': {
            width: drawerWidth,
            background: theme.palette.background.default,
            color: theme.palette.text.primary,
            borderRight: 'none',
            [theme.breakpoints.up('md')]: {
              top: '88px'
            }
          }
        }}
        ModalProps={{ keepMounted: true }}
        color="inherit"
      >
        {drawerOpen && logo}
        {drawerOpen && drawer}
      </Drawer>
    </Box>
  );
};

Sidebar.propTypes = {
  window: PropTypes.object
};

export default memo(Sidebar);
