import { createSlice } from '@reduxjs/toolkit';

import { viirsLayer, viirsMultiYearLayer } from 'config/layers';

// All layer configs must include the following keys:
// 'id', 'name', 'description', 'on'
// Layers may include the 'enabled' key, will default to false if not included
// The 'on' key refers to the 'map.on()' function, all keys in the 'on' object
//   will be executed with 'map.on(key, fn)' (refer to the viirs layer for an example)

const layerConfigs = [{ ...viirsMultiYearLayer }, { ...viirsLayer }];

export const LayerStylesEnum = {
  Type: 'type',
  Temp: 'temp',
  Energy: 'energy'
};

const initialState = {
  style: LayerStylesEnum.Type,
  isRadiant: false,
  layers: layerConfigs.map((config) => ({
    ...config,
    enabled: config.enabled || false
  }))
};

const layers = createSlice({
  name: 'layers',
  initialState,
  reducers: {
    setLayers(state, action) {
      state.layers = action.payload;
    },

    toggleLayerEnabled(state, action) {
      console.log('toggle layer: ', action.payload);
      const layerIndex = state.layers.findIndex((layer) => layer.id === action.payload);
      console.log('new state: ', !state.layers[layerIndex].enabled);
      if (layerIndex !== -1) {
        state.layers[layerIndex].enabled = !state.layers[layerIndex].enabled;
      }
    },

    toggleIsRadiant(state) {
      state.isRadiant = !state.isRadiant;
    },

    setLayerStyle(state, action) {
      state.style = action.payload;
    }
  }
});

export default layers.reducer;
export const { setLayers, toggleLayerEnabled, toggleIsRadiant, setLayerStyle } = layers.actions;
