import { useState } from 'react';
import { useTheme } from '@mui/material/styles';
import { Stack, Typography, useMediaQuery } from '@mui/material';

import LoginForm from './LoginForm';
import LoginButton from './LoginButton';
import { useDispatch } from 'store';
import { login, setLoading } from 'store/slices/user';

import Logo from 'assets/images/logo.png';

export default function LoginComponent() {
  const theme = useTheme();
  const dispatch = useDispatch();
  const matchDownSM = useMediaQuery(theme.breakpoints.down('md'));
  const [username, setUsername] = useState('');
  const [password, setPassword] = useState('');

  const handleLogin = async () => {
    dispatch(setLoading(true));
    setTimeout(() => dispatch(login(username, password)), 1000);
  };

  return (
    <Stack spacing={3} mt={8} onKeyPress={(e) => e.key === 'Enter' && handleLogin()}>
      <img src={Logo} alt="logo" style={{ width: '400px' }} />
      <Typography variant="caption" fontSize="14px" textAlign={matchDownSM ? 'center' : 'inherit'}>
        Enter your credentials to continue
      </Typography>
      <LoginForm formData={{ username, password, setUsername, setPassword }} />
      <LoginButton onClick={handleLogin} />
    </Stack>
  );
}
