import PropTypes from 'prop-types';
import Chart from 'react-apexcharts';

export default function MethaneChart({ chartData }) {
  if (chartData === null) {
    return <></>;
  }
  let { methane } = chartData;
  methane = methane.map((item) => {
    item.y *= 1000;
    return item;
  });
  const maxValue = methane.length ? methane.reduce((a, b) => (a.y > b.y ? a : b)).y : 2;
  const categories = methane.map((value) => value.label);

  const colors = ['#0f1ef5', '#f50f45', '#f50f45'];
  const chartConfig = {
    height: 215,
    options: {
      chart: {
        id: 'bar-chart',
        stacked: true,
        toolbar: {
          show: false
        },
        zoom: {
          enabled: false
        }
      },
      responsive: [
        {
          breakpoint: 480,
          options: {
            legend: {
              position: 'bottom',
              offsetX: -10,
              offsetY: 0
            }
          }
        }
      ],
      title: {
        text: 'Flared Gas Flow Rate (mmscm/d)',
        align: 'left'
      },
      grid: {
        show: true,
        borderColor: '#000000',
        strokeDashArray: 0,
        position: 'back',
        xaxis: {
          lines: {
            show: true
          }
        },
        yaxis: {
          lines: {
            show: true
          }
        },
        row: {
          colors: ['#f2f2f7'],
          opacity: 1
        },
        column: {
          colors: ['#f2f2f7'],
          opacity: 1
        }
      },
      xaxis: {
        categories,
        decimalsInFloat: 0,
        tooltip: {
          enabled: false
        },
        type: 'numeric'
      },
      yaxis: {
        decimalsInFloat: 4,
        labels: {
          maxWidth: 40,
          minWidth: 10,
          show: true
        },
        min: 0,
        max: Math.ceil(maxValue),
        reversed: false,
        tickAmount: 4
      },
      colors,
      stroke: {
        width: [2, 2],
        curve: 'smooth',
        dashArray: [8, 8]
      },
      markers: {
        size: [5, 5, 5],
        shape: 'circle',
        hover: {
          size: 8
        }
      },
      legend: {
        show: false
      },
      tooltip: {
        enabled: true,
        x: {
          show: true
        }
      }
    }
  };
  const series = [
    {
      name: 'Flared Gas Flow Rate',
      type: 'scatter',
      data: methane
    }
  ];
  return <Chart {...chartConfig} series={series} />;
}

MethaneChart.propTypes = {
  chartData: PropTypes.object
};
