import PropTypes from 'prop-types';
import Chart from 'react-apexcharts';

export default function RadianceChart({ chartData }) {
  if (chartData === null) {
    return <></>;
  }

  const { rh: radiance } = chartData;
  const maxValue = radiance.length ? radiance.reduce((a, b) => (a.y > b.y ? a : b)).y : 10;
  const categories = radiance.map((value) => value.label);

  const colors = ['#0f1ef5', '#f50f45', '#f50f45'];

  const chartConfig = {
    height: 215,
    options: {
      chart: {
        id: 'basic-bar',
        stacked: true,
        toolbar: {
          show: false
        },
        zoom: {
          enabled: false
        }
      },
      responsive: [
        {
          breakpoint: 480,
          options: {
            legend: {
              position: 'bottom',
              offsetX: -10,
              offsetY: 0
            }
          }
        }
      ],
      title: {
        text: 'Radiance M10 (W/m2/sr/um)',
        align: 'left'
      },
      grid: {
        show: true,
        borderColor: '#000000',
        // strokeDashArray: 0,
        // position: 'back',
        xaxis: {
          lines: {
            show: true
          }
        },
        yaxis: {
          lines: {
            show: true
          }
        },
        row: {
          colors: ['#f2f2f7'],
          opacity: 1
        },
        column: {
          colors: ['#f2f2f7'],
          opacity: 1
        }
      },
      xaxis: {
        categories,
        decimalsInFloat: 0,
        tooltip: {
          enabled: false
        },
        type: 'numeric'
      },
      yaxis: {
        decimalsInFloat: 2,
        labels: {
          maxWidth: 40,
          minWidth: 10,
          show: true
        },
        min: 0,
        max: Math.ceil(maxValue),
        tickAmount: 5
      },
      colors,
      stroke: {
        width: [2, 2],
        curve: 'smooth',
        dashArray: [8, 8]
      },
      markers: {
        size: [5, 5, 5],
        shape: 'circle',
        hover: {
          size: 8
        }
        // discrete: getDiscretes()
      },
      legend: {
        show: false
      },
      tooltip: {
        enabled: true,
        x: {
          show: true
        }
      }
    }
  };
  const series = [
    {
      name: 'Radiance M10',
      type: 'scatter',
      data: radiance
    }
  ];

  return <Chart {...chartConfig} series={series} />;
}

RadianceChart.propTypes = {
  chartData: PropTypes.object
};
