import PropTypes from 'prop-types';
import Chart from 'react-apexcharts';

export default function TemperatureChart({ chartData }) {
  if (chartData === null) {
    return <></>;
  }

  const { temperature } = chartData;
  const maxValue = temperature.length ? temperature.reduce((a, b) => (a.y > b.y ? a : b)).y : 3500;
  const categories = temperature.map((value) => value.label);

  const colors = ['#0f1ef5', '#f50f45', '#000000'];

  const chartConfig = {
    height: 215,
    options: {
      chart: {
        id: 'bar-chart',
        stacked: true,
        toolbar: {
          show: false
        },
        zoom: {
          enabled: false
        }
      },
      responsive: [
        {
          breakpoint: 480,
          options: {
            legend: {
              position: 'bottom',
              offsetX: -10,
              offsetY: 0
            }
          }
        }
      ],
      title: {
        text: 'Temperature (K)',
        align: 'left'
      },
      grid: {
        show: true,
        borderColor: '#000000',
        xaxis: {
          lines: {
            show: true
          }
        },
        yaxis: {
          lines: {
            show: true
          }
        },
        row: {
          colors: ['#f2f2f7'],
          opacity: 1
        },
        column: {
          colors: ['#f2f2f7'],
          opacity: 1
        }
      },
      xaxis: {
        categories,
        decimalsInFloat: 0,
        tooltip: {
          enabled: false
        },
        type: 'numeric'
      },
      yaxis: {
        // decimalsInFloat: 2,
        labels: {
          // formatter: (val) => Math.trunc(val),
          maxWidth: 40,
          minWidth: 10,
          show: true
        },
        min: 0,
        max: Math.ceil(maxValue),
        reversed: false,
        tickAmount: 7
      },
      colors,
      stroke: {
        width: [2, 2],
        curve: 'straight',
        dashArray: [0, 0, 8]
      },
      markers: {
        size: [5, 5, 0],
        shape: 'circle',
        hover: {
          size: 8
        }
      },
      legend: {
        show: false
      },
      tooltip: {
        enabled: true,
        x: {
          show: true
        }
      }
    }
  };

  const series = [
    {
      name: 'Temperature (K)',
      type: 'scatter',
      data: temperature
    }
  ];

  return <Chart {...chartConfig} series={series} />;
}

TemperatureChart.propTypes = {
  chartData: PropTypes.object
};
