import PropTypes from 'prop-types';
import { ToggleButton, ToggleButtonGroup, Tooltip } from '@mui/material';

import CalendarMonthIcon from '@mui/icons-material/CalendarMonth';
import CalendarTodayIcon from '@mui/icons-material/CalendarToday';
import styled from '@emotion/styled';

const ToggleContainer = styled.div`
  position: absolute;
  right: 125px;
  top: 100px;
`;

export const ToggleEnum = {
  monthly: 'monthly',
  yearly: 'yearly'
};

export default function TimeToggle({ toggleState, setToggleState }) {
  const handleToggle = (event, newState) => {
    if (newState) {
      setToggleState(newState);
    }
  };

  return (
    <ToggleContainer>
      <ToggleButtonGroup
        value={toggleState}
        exclusive
        onChange={handleToggle}
        aria-label="monthly vs yearly toggle button"
        color="secondary"
      >
        <Tooltip title="Monthly">
          <ToggleButton
            value={ToggleEnum.monthly}
            aria-label={ToggleEnum.monthly}
            selected={toggleState === ToggleEnum.monthly}
          >
            <CalendarMonthIcon />
          </ToggleButton>
        </Tooltip>
        <Tooltip title="Yearly">
          <ToggleButton
            value={ToggleEnum.yearly}
            aria-label={ToggleEnum.yearly}
            selected={toggleState === ToggleEnum.yearly}
          >
            <CalendarTodayIcon />
          </ToggleButton>
        </Tooltip>
      </ToggleButtonGroup>
    </ToggleContainer>
  );
}

TimeToggle.propTypes = {
  toggleState: PropTypes.string,
  setToggleState: PropTypes.func
};
