import { useEffect, useState } from 'react';
import { Grid, Stack, Typography } from '@mui/material';

import Legend from './Legend';
import MethaneChart from './MethaneChart';
import RadianceChart from './RadianceChart';
import TemperatureChart from './TemperatureChart';
import { axiosApi } from 'utils/axios';
import { useSelector } from 'store';
import TimeToggle, { ToggleEnum } from './TimeToggle';
import { getChartUrlFromLayerId } from 'utils/layerUtils';

export default function Chart() {
  const [toggleState, setToggleState] = useState(ToggleEnum.yearly);
  const [chartData, setChartData] = useState(null);
  const dashboardState = useSelector((state) => state.dashboard);
  const { id: emitterId, layerId } = dashboardState.selectedEmitterProps;

  const loadChartData = async (url) => {
    const { data } = await axiosApi.get(url);
    setChartData(data);
    console.log('chart data: ', data);
  };

  useEffect(() => {
    loadChartData(getChartUrlFromLayerId(layerId, emitterId, toggleState));
  }, [emitterId, layerId, toggleState]);

  return (
    <Grid item xs={12}>
      <Legend chartData={chartData} />
      <Stack>
        <RadianceChart chartData={chartData} />
        <TemperatureChart chartData={chartData} />
        <MethaneChart chartData={chartData} />
        <Typography>
          VIIRS Nightfire temporal profile created by the Earth Observation Group, Payne Institution
          for public policy, Colorado School of Mines
        </Typography>
      </Stack>
      <TimeToggle toggleState={toggleState} setToggleState={setToggleState} />
    </Grid>
  );
}
