import PropTypes from 'prop-types';
import { useState } from 'react';
import { Box, Menu, MenuItem, Tooltip, Typography, useTheme } from '@mui/material';

import { getCsvUrlFromLayerId } from 'utils/layerUtils';

import { IconDownload } from '@tabler/icons';

export default function DownloadMenu({ layerId, emitterId }) {
  const theme = useTheme();
  const [anchorEl, setAnchorEl] = useState(null);
  const [isHovered, setIsHovered] = useState(false);
  const open = Boolean(anchorEl);

  const handleClick = (event) => {
    setAnchorEl(event.currentTarget);
  };

  const handleClose = () => {
    setAnchorEl(null);
  };

  const csvUrl = getCsvUrlFromLayerId(layerId, emitterId);
  const csvUrlArray = csvUrl.split('/');
  const csvFilenameIndex = csvUrlArray.length - 1;
  const csvFilename = csvUrlArray[csvFilenameIndex];
  const monthlyCsvFilename = `flare_${emitterId}_${layerId}_month_vnf_series.csv`;
  const monthlyCsvUrl = getCsvUrlFromLayerId(layerId, emitterId, 'month');
  const yearlyCsvFilename = `flare_${emitterId}_${layerId}_year_vnf_series.csv`;
  const yearlyCsvUrl = getCsvUrlFromLayerId(layerId, emitterId, 'year');

  return (
    <>
      <Tooltip title="Download CSV">
        <Box
          onClick={handleClick}
          onMouseEnter={() => setIsHovered(true)}
          onMouseLeave={() => setIsHovered(false)}
          style={{
            display: 'flex',
            padding: '5px',
            borderRadius: '8px',
            textDecoration: 'none',
            cursor: 'pointer',
            justifyContent: 'center',
            alignItems: 'center',
            color: theme.palette.primary.light,
            background: isHovered ? theme.palette.primary.dark : theme.palette.primary.main,
            fontWeight: 'bold',
            marginRight: '15px',
            height: '33px',
            width: '33px'
          }}
        >
          <IconDownload />
        </Box>
      </Tooltip>
      <Menu
        id="download-menu"
        anchorEl={anchorEl}
        open={open}
        onClose={handleClose}
        MenuListProps={{
          'aria-labelledby': 'basic-button'
        }}
      >
        <MenuItem onClick={handleClose}>
          <a href={csvUrl} download={csvFilename}>
            <Typography variant="h6">Download Nightly Data</Typography>
          </a>
        </MenuItem>
        <MenuItem onClick={handleClose}>
          <a href={monthlyCsvUrl} download={monthlyCsvFilename}>
            <Typography variant="h6">Download Monthly Data</Typography>
          </a>
        </MenuItem>
        <MenuItem onClick={handleClose}>
          <a href={yearlyCsvUrl} download={yearlyCsvFilename}>
            <Typography variant="h6">Download Yearly Data</Typography>
          </a>
        </MenuItem>
      </Menu>
    </>
  );
}

DownloadMenu.propTypes = {
  layerId: PropTypes.string,
  emitterId: PropTypes.number
};
