import { useTheme } from '@mui/material/styles';
import { Box, Grid, Stack, Typography } from '@mui/material';
import {
  IconCategory2,
  IconAffiliate,
  IconSatellite,
  IconZoomCheck,
  IconGlobe,
  IconIdBadge2
} from '@tabler/icons';
import { useSelector } from 'store';

export default function ProfileDataContent() {
  const theme = useTheme();
  const dashboardState = useSelector((state) => state.dashboard);
  const { selectedEmitterProps } = dashboardState;
  const { id: emitterId, type, category, lat, lon, iso } = selectedEmitterProps;

  const coordinateBoxStyle = {
    display: 'flex',
    justifyContent: 'space-between',
    width: '75px'
  };

  return (
    <Grid container>
      <Grid item xs={12}>
        <Grid container alignItems="center" justifyContent="space-between">
          <Grid item xs zeroMinWidth>
            <Grid container>
              <Grid item xs={12}>
                <Grid
                  sx={{
                    '& svg': {
                      borderRadius: '5px',
                      width: 40,
                      height: 40,
                      color: '#F43B2E',
                      p: 0.65,
                      bgcolor:
                        theme.palette.mode === 'dark' ? theme.palette.background.default : '#FFE9E9'
                    }
                  }}
                >
                  <Grid container>
                    <Grid item xs={1.5}>
                      <Grid container alignItems="center" spacing={1} justifyContent="flex-end">
                        <Grid item>
                          <IconZoomCheck stroke={1.5} />
                        </Grid>
                        <Grid item>
                          <Typography variant="h5" align="left">
                            ISO
                          </Typography>
                          <Typography variant="subtitle2" align="left">
                            {iso ?? 'unknown'}
                          </Typography>
                        </Grid>
                      </Grid>
                    </Grid>
                    <Grid item xs={2}>
                      <Grid container alignItems="center" spacing={1} justifyContent="center">
                        <Grid item>
                          <IconGlobe stroke={1.5} />
                        </Grid>
                        <Grid item>
                          <Stack>
                            <Box style={coordinateBoxStyle}>
                              <Typography variant="h5" align="left">
                                Lat:
                              </Typography>
                              <Typography variant="subtitle2" align="left">
                                {parseFloat(lat).toFixed(3)}
                              </Typography>
                            </Box>
                            <Box style={coordinateBoxStyle}>
                              <Typography variant="h5" align="left">
                                Lon:
                              </Typography>
                              <Typography variant="subtitle2" align="left">
                                {parseFloat(lon).toFixed(3)}
                              </Typography>
                            </Box>
                          </Stack>
                        </Grid>
                      </Grid>
                    </Grid>
                    <Grid item xs={1.5}>
                      <Grid container alignItems="center" spacing={1} justifyContent="flex-start">
                        <Grid item>
                          <IconCategory2 stroke={1.5} />
                        </Grid>
                        <Grid item>
                          <Typography variant="h5" align="left">
                            Type
                          </Typography>
                          <Typography variant="subtitle2" align="left">
                            {type ?? 'unknown'}
                          </Typography>
                        </Grid>
                      </Grid>
                    </Grid>
                    <Grid item xs={1.5}>
                      <Grid container alignItems="center" spacing={1} justifyContent="flex-start">
                        <Grid item>
                          <IconAffiliate stroke={1.5} />
                        </Grid>
                        <Grid item>
                          <Typography variant="h5" align="left">
                            Category
                          </Typography>
                          <Typography variant="subtitle2" align="left">
                            {category ?? 'unknown'}
                          </Typography>
                        </Grid>
                      </Grid>
                    </Grid>
                    <Grid item xs={1.5}>
                      <Grid container alignItems="center" spacing={1} justifyContent="flex-start">
                        <Grid item>
                          <IconIdBadge2 stroke={1.5} />
                        </Grid>
                        <Grid item>
                          <Typography variant="h5" align="left">
                            ID
                          </Typography>
                          <Typography variant="subtitle2" align="left">
                            {emitterId}
                          </Typography>
                        </Grid>
                      </Grid>
                    </Grid>
                    <Grid item xs={2}>
                      <Grid container alignItems="center" spacing={1} justifyContent="flex-start">
                        <Grid item>
                          <IconSatellite stroke={1.5} />
                        </Grid>
                        <Grid item>
                          <Typography variant="h5" align="left">
                            Satellites
                          </Typography>
                          <Typography variant="subtitle2" align="left">
                            SNPP & NOAA-20
                          </Typography>
                        </Grid>
                      </Grid>
                    </Grid>
                  </Grid>
                </Grid>
              </Grid>
            </Grid>
          </Grid>
        </Grid>
      </Grid>
    </Grid>
  );
}
