import PropTypes from 'prop-types';
import { ToggleButton, ToggleButtonGroup, Tooltip } from '@mui/material';

import { IconChartInfographic, IconLifebuoy, IconPhoto } from '@tabler/icons';

const ICON_SIZE = 30;

export default function ToggleButtons({ selectedTab, setSelectedTab }) {
  const handleFormat = (event, newFormats) => {
    if (newFormats !== null) {
      setSelectedTab(newFormats);
    }
  };

  return (
    <ToggleButtonGroup
      value={selectedTab}
      onChange={handleFormat}
      aria-label="text formatting"
      color="secondary"
      exclusive
    >
      <Tooltip title="Profile Image">
        <ToggleButton value="image" selected={selectedTab === 'image'}>
          <IconPhoto size={ICON_SIZE} />
        </ToggleButton>
      </Tooltip>
      <Tooltip title="Interactive Chart">
        <ToggleButton value="chart" selected={selectedTab === 'chart'}>
          <IconChartInfographic size={ICON_SIZE} />
        </ToggleButton>
      </Tooltip>
      <Tooltip title="Guide">
        <ToggleButton value="guide" selected={selectedTab === 'guide'}>
          <IconLifebuoy size={ICON_SIZE} />
        </ToggleButton>
      </Tooltip>
    </ToggleButtonGroup>
  );
}

ToggleButtons.propTypes = {
  selectedTab: PropTypes.string,
  setSelectedTab: PropTypes.func
};
