import PropTypes from 'prop-types';
import styled from '@emotion/styled';
import { Box, Typography } from '@mui/material';

import ProfileDataContent from './ProfileDataContent';
import DownloadMenu from './DownloadMenu';
import isAuthorized from 'utils/auth';
import ToggleButtons from './ToggleButtons';
import { AuthRoles } from 'store/slices/user';
import { useSelector } from 'store';

const StyledHeader = styled.header`
  padding: 15px;
  display: flex;
  justify-content: space-between;
  align-items: center;
  margin-right: 50px;
`;
export default function Header({ selectedTab, setSelectedTab, layerId, emitterId }) {
  const userState = useSelector((state) => state.user);
  return (
    <StyledHeader>
      <Typography variant="h3" style={{ width: '600px' }}>
        VIIRS Nightfire Temporal Profile: {emitterId}
      </Typography>
      {isAuthorized(userState, AuthRoles.User) && (
        <>
          {selectedTab === 'guide' ? null : <ProfileDataContent />}
          <Box style={{ display: 'flex', alignItems: 'center' }}>
            <DownloadMenu layerId={layerId} emitterId={emitterId} />
            <ToggleButtons selectedTab={selectedTab} setSelectedTab={setSelectedTab} />
          </Box>
        </>
      )}
    </StyledHeader>
  );
}

Header.propTypes = {
  selectedTab: PropTypes.string,
  setSelectedTab: PropTypes.func,
  layerId: PropTypes.string,
  emitterId: PropTypes.number
};
