import PropTypes from 'prop-types';
import styled from '@emotion/styled';
import { useState } from 'react';
import { Box, Divider, Modal } from '@mui/material';

import Chart from './Chart';
import isAuthorized from 'utils/auth';
import RestrictedAccess from 'ui-component/RestrictedAccess';
import TemporalProfileButton from './TemporalProfileButton';
import { AuthRoles } from 'store/slices/user';
import { useSelector } from 'store';
import { getProfileUrlFromLayerId } from 'utils/layerUtils';

import CloseIcon from '@mui/icons-material/Close';
import Header from './Header';

const ModalContent = styled(Box)`
  position: absolute;
  top: 50px;
  left: 100px;
  width: calc(100vw - 200px);
  height: calc(100vh - 100px);
  background: white;
`;

const CloseIconContainer = styled.div`
  position: absolute;
  top: 5px;
  right: 5px;
  cursor: pointer;
`;

const ContentContainer = styled.div`
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  height: calc(100vh - 198px);
`;

const imageStyle = {
  height: '100%',
  maxWidth: '95%'
};

export default function TemporalProfileModal({ open, setOpen }) {
  const userState = useSelector((state) => state.user);
  const [selectedTab, setSelectedTab] = useState('image');
  const dashboardState = useSelector((state) => state.dashboard);
  const { id: emitterId, layerId } = dashboardState.selectedEmitterProps;

  const profileUrl = getProfileUrlFromLayerId(layerId, emitterId);

  const handleOpen = () => setOpen(true);
  const handleClose = () => setOpen(false);

  const ChartImage = () => <img src={profileUrl} alt="Flare" style={imageStyle} />;

  const ImageData = () => (
    <img
      src="/giree/resources/images/readmeprofiles/readme-catalog-profiles.jpg"
      alt="Tutorial"
      style={imageStyle}
    />
  );

  const CurrentContent = () => {
    switch (selectedTab) {
      case 'chart':
        return <Chart />;
      case 'guide':
        return <ImageData />;
      default:
        return <ChartImage />;
    }
  };

  return (
    <>
      <TemporalProfileButton onClick={handleOpen} />
      <Modal open={open} onClose={handleClose}>
        <ModalContent>
          <CloseIconContainer onClick={handleClose}>
            <CloseIcon />
          </CloseIconContainer>
          <Header
            selectedTab={selectedTab}
            setSelectedTab={setSelectedTab}
            layerId={layerId}
            emitterId={emitterId}
          />
          <Divider />
          <ContentContainer>
            {isAuthorized(userState, AuthRoles.User) ? (
              <CurrentContent />
            ) : (
              <Box style={{ width: '650px' }}>
                <RestrictedAccess />
              </Box>
            )}
          </ContentContainer>
        </ModalContent>
      </Modal>
    </>
  );
}

TemporalProfileModal.propTypes = {
  open: PropTypes.bool.isRequired,
  setOpen: PropTypes.func.isRequired
};
