import PropTypes from 'prop-types';

import { useTheme } from '@mui/material/styles';
import { Button, Card, CardContent, CardMedia, Grid, Typography } from '@mui/material';

import { gridSpacing } from 'store/constant';

const BackgroundProfileCard = ({ name, description, thumbnail, clickHandler, isSelected }) => {
  const theme = useTheme();

  return (
    <Card
      sx={{
        background:
          theme.palette.mode === 'dark' ? theme.palette.dark.main : theme.palette.grey[50],
        border: theme.palette.mode === 'dark' ? 'none' : '1px solid',
        borderColor: theme.palette.grey[100],
        textAlign: 'center'
      }}
    >
      <CardMedia
        component="img"
        image={thumbnail}
        title="Background Thumbnail"
        sx={{ height: '125px' }}
      />
      <CardContent sx={{ p: 2, pb: '16px !important' }}>
        <Grid container spacing={gridSpacing}>
          <Grid item xs={12} alignItems="center">
            <Grid container spacing={1}>
              <Grid item xs={12}>
                <Typography variant="h4">{name}</Typography>
              </Grid>
              <Grid item xs={12}>
                <Typography variant="body2" style={{ minHeight: '45px' }}>
                  {description}
                </Typography>
              </Grid>
            </Grid>
          </Grid>
          <Grid item xs={12}>
            <Button
              variant={isSelected ? 'contained' : 'outlined'}
              onClick={clickHandler}
              fullWidth
            >
              {isSelected ? 'Selected' : 'Select'}
            </Button>
          </Grid>
        </Grid>
      </CardContent>
    </Card>
  );
};

BackgroundProfileCard.propTypes = {
  name: PropTypes.string,
  description: PropTypes.string,
  thumbnail: PropTypes.string,
  clickHandler: PropTypes.func,
  isSelected: PropTypes.bool
};

export default BackgroundProfileCard;
