import { useEffect, useState } from 'react';

import { Grid, Typography } from '@mui/material';

import BackgroundProfileCard from 'views/backgrounds/BackgroundProfileCard';
import MainCard from 'ui-component/cards/MainCard';
import { gridSpacing } from 'store/constant';
import { useSelector, dispatch } from 'store';
import { setBackground } from 'store/slices/backgrounds';

import backgrounds from 'config/backgroundsConfig.json';

const Backgrounds = () => {
  const [title, setTitle] = useState('Backgrounds');
  const backgroundsState = useSelector((state) => state.backgrounds);

  useEffect(() => {
    if (backgroundsState.bgSelected) {
      setTitle(backgroundsState.bgSelected.name);
    }
  }, [backgroundsState.bgSelected]);

  return (
    <MainCard title={<Typography variant="h3">Backgrounds: {title}</Typography>}>
      <Grid container direction="row" spacing={gridSpacing}>
        {backgrounds?.map((bg, index) => {
          const isSelected = () => bg.name === backgroundsState.bgSelected.name;
          const handleClick = () => {
            dispatch(setBackground(bg));
          };
          return (
            <Grid key={`grid-item-background-${index}`} item xs={12} sm={6} lg={4} xl={3}>
              <BackgroundProfileCard {...bg} clickHandler={handleClick} isSelected={isSelected()} />
            </Grid>
          );
        })}
      </Grid>
    </MainCard>
  );
};

export default Backgrounds;
