import { Card, CardContent, Grid, Typography } from '@mui/material';
import { dispatch, useSelector } from 'store';

import { useTheme } from '@mui/material/styles';

import { ContextEnum, setCurrentContext } from 'store/slices/dashboard';
import isAuthorized from 'utils/auth';
import { AuthRoles } from 'store/slices/user';

export default function EditButton() {
  const theme = useTheme();
  const userState = useSelector((state) => state.user);
  const { isLoggedIn } = userState;

  const enableColor = {
    color: '#fafafa'
  };

  const enableBackgroundColor = {
    background: theme.palette.primary.main,
    position: 'relative',
    color: '#fff',
    cursor: 'pointer'
  };

  const handleClickEdit = () => {
    dispatch(setCurrentContext(ContextEnum.Edit));
  };

  const isDisabled = () => {
    if (isLoggedIn) {
      if (isAuthorized(userState, AuthRoles.Admin)) {
        return false;
      }
    }
    return true;
  };

  if (isDisabled()) {
    return <></>;
  }

  return (
    <Card onClick={handleClickEdit} sx={enableBackgroundColor}>
      <CardContent style={{ padding: '7px' }}>
        <Grid container direction="row" justifyContent="center" alignItems="center" spacing={1}>
          <Grid item>
            <Typography variant="h4" align="left" sx={enableColor}>
              Admin only: Edit
            </Typography>
          </Grid>
        </Grid>
      </CardContent>
    </Card>
  );
}
