import PropTypes from 'prop-types';
import { Card, Grid, Typography, Tooltip, IconButton } from '@mui/material';
import { CopyToClipboard } from 'react-copy-to-clipboard';

import FlagIcon from '@mui/icons-material/Flag';
import CategoryIcon from '@mui/icons-material/Category';
import ThermostatIcon from '@mui/icons-material/Thermostat';
import LocationOnIcon from '@mui/icons-material/LocationOn';
import ContentCopyTwoToneIcon from '@mui/icons-material/ContentCopyTwoTone';
import BorderAllIcon from '@mui/icons-material/BorderAll';
import LocalFireDepartmentIcon from '@mui/icons-material/LocalFireDepartment';
import PropaneTankIcon from '@mui/icons-material/PropaneTank';
import TerrainIcon from '@mui/icons-material/Terrain';
import RadarIcon from '@mui/icons-material/Radar';

import getCountryNameFromIso from 'utils/isoToCountryConverter';
import LinkNavigator from './LinkNavigator';
import { gridSpacing } from 'store/constant';
import { useDispatch, useSelector } from 'store';
import { openSnackbar } from 'store/slices/snackbar';

export default function FileCards({ emitterProps }) {
  const dispatch = useDispatch();
  const filterState = useSelector((state) => state.filters);
  const { countries } = filterState;
  const {
    lat,
    lon,
    type,
    category,
    iso,
    t_mean: tMean,
    rh,
    bcm,
    area,
    pct,
    COUNTRY
  } = emitterProps;
  const locationValue = `${lat},${lon}`;

  return (
    <Card
      sx={{
        p: 3
      }}
    >
      <Grid container spacing={gridSpacing}>
        <Grid item xs={12}>
          <Grid container spacing={gridSpacing}>
            <Grid item xs={7}>
              <Grid container spacing={1}>
                <Grid item>
                  <BorderAllIcon sx={{ fontSize: '1rem' }} />
                </Grid>
                <Grid item>
                  <Typography variant="caption">Type</Typography>
                </Grid>
              </Grid>
              <Typography variant="h5" style={{ paddingLeft: '13px' }}>
                {type || 'unknown'}
              </Typography>
            </Grid>
            <Grid item xs={5}>
              <Grid container spacing={1}>
                <Grid item>
                  <CategoryIcon sx={{ fontSize: '1rem' }} />
                </Grid>
                <Grid item>
                  <Typography variant="caption">Category</Typography>
                </Grid>
              </Grid>
              <Typography variant="h5" style={{ paddingLeft: '13px' }}>
                {category || 'none'}
              </Typography>
            </Grid>
          </Grid>
        </Grid>
        <Grid item xs={12}>
          <Grid container spacing={gridSpacing}>
            <Grid item xs={7}>
              <Grid container spacing={1}>
                <Grid item>
                  <FlagIcon sx={{ fontSize: '1rem' }} />
                </Grid>
                <Grid item>
                  <Typography variant="caption">Country</Typography>
                </Grid>
              </Grid>
              <Typography variant="h5" style={{ paddingLeft: '13px' }}>
                {getCountryNameFromIso(countries, iso, COUNTRY)}
              </Typography>
            </Grid>
            <Grid item xs={5}>
              <Grid container spacing={1}>
                <Grid item>
                  <ThermostatIcon sx={{ fontSize: '1rem' }} />
                </Grid>
                <Grid item>
                  <Typography variant="caption">Temperature</Typography>
                </Grid>
              </Grid>
              <Typography variant="h5" style={{ paddingLeft: '13px' }}>
                {(tMean && parseInt(tMean, 10).toLocaleString()) || 'unknown'} K
              </Typography>
            </Grid>
          </Grid>
        </Grid>
        <Grid item xs={12}>
          <Grid container spacing={gridSpacing}>
            <Grid item xs={7}>
              <Grid container spacing={1}>
                <Grid item>
                  <LocalFireDepartmentIcon sx={{ fontSize: '1rem' }} />
                </Grid>
                <Grid item>
                  <Typography variant="caption">Radiant Heat</Typography>
                </Grid>
              </Grid>
              <Typography variant="h5" style={{ paddingLeft: '13px' }}>
                {(rh && parseFloat(rh).toFixed(2)) || 'unknown'} MW
              </Typography>
            </Grid>
            <Grid item xs={5}>
              <Grid container spacing={1}>
                <Grid item>
                  <PropaneTankIcon sx={{ fontSize: '1rem' }} />
                </Grid>
                <Grid item>
                  <Typography variant="caption">Flared Gas</Typography>
                </Grid>
              </Grid>
              <Typography variant="h5" style={{ paddingLeft: '13px' }}>
                {(bcm && parseFloat(bcm * 1000).toFixed(3)) || 'unknown'} mcm/yr
              </Typography>
            </Grid>
          </Grid>
        </Grid>
        <Grid item xs={12}>
          <Grid container spacing={gridSpacing}>
            <Grid item xs={7}>
              <Grid container spacing={1}>
                <Grid item>
                  <TerrainIcon sx={{ fontSize: '1rem' }} />
                </Grid>
                <Grid item>
                  <Typography variant="caption">Area</Typography>
                </Grid>
              </Grid>
              <Typography variant="h5" style={{ paddingLeft: '13px' }}>
                {(area && parseFloat(parseFloat(area).toFixed(1)).toLocaleString()) || 'unknown'} m
                <sup>2</sup>
              </Typography>
            </Grid>
            <Grid item xs={5}>
              <Grid container spacing={1}>
                <Grid item>
                  <RadarIcon sx={{ fontSize: '1rem' }} />
                </Grid>
                <Grid item>
                  <Typography variant="caption">Detection Frequency</Typography>
                </Grid>
              </Grid>
              <Typography variant="h5" style={{ paddingLeft: '13px' }}>
                {(pct && parseFloat(pct * 100).toFixed(2)) || 'unknown'}%
              </Typography>
            </Grid>
          </Grid>
        </Grid>
        <Grid item xs={12}>
          <Grid container spacing={gridSpacing}>
            <Grid item xs={12}>
              <Grid container spacing={1}>
                <Grid item>
                  <LocationOnIcon sx={{ fontSize: '1rem' }} />
                </Grid>
                <Grid item>
                  <Typography variant="caption">Location</Typography>
                </Grid>
              </Grid>
              <Grid item>
                <Typography variant="h5" style={{ paddingLeft: '13px' }}>
                  {`${lat.toFixed(6)}, ${lon.toFixed(6)}`}
                  <CopyToClipboard
                    text={locationValue}
                    style={{ paddingLeft: '8px' }}
                    onCopy={() =>
                      dispatch(
                        openSnackbar({
                          open: true,
                          message: 'Location Copied',
                          variant: 'alert',
                          alert: {
                            color: 'success'
                          },
                          close: false,
                          anchorOrigin: { vertical: 'top', horizontal: 'center' },
                          transition: 'SlideCenter'
                        })
                      )
                    }
                  >
                    <Tooltip title="Copy">
                      <IconButton
                        size="medium"
                        sx={{ px: 0, marginLeft: '5px', marginRight: '15px' }}
                      >
                        <ContentCopyTwoToneIcon sx={{ fontSize: '1.1rem' }} />
                      </IconButton>
                    </Tooltip>
                  </CopyToClipboard>
                  <LinkNavigator emitterProps={emitterProps} />
                </Typography>
              </Grid>
            </Grid>
          </Grid>
        </Grid>
      </Grid>
    </Card>
  );
}

FileCards.propTypes = {
  emitterProps: PropTypes.object
};
