import PropTypes from 'prop-types';
import { useState } from 'react';

import Button from '@mui/material/Button';
import Menu from '@mui/material/Menu';
import MenuItem from '@mui/material/MenuItem';
import Link from '@mui/material/Link';

export default function BasicMenu({ emitterProps }) {
  const { id, lat, lon } = emitterProps;
  const zoom = 17;
  const [anchorEl, setAnchorEl] = useState(null);
  const open = Boolean(anchorEl);
  const handleClick = (event) => {
    setAnchorEl(event.currentTarget);
  };
  const handleClose = () => {
    setAnchorEl(null);
  };
  const gMap = `https://www.google.com/maps/?q=loc:${lat},${lon}&z=${zoom}`;
  const bMap = `https://www.bing.com/maps/?cp=${lat}%7E${lon}&lvl=${zoom}&style=a&sp=point.${lat}_${lon}_ID:${id}`;
  const esriMap = `https://www.arcgis.com/home/webmap/viewer.html?center=${lon},${lat}&level=${zoom}&basemapUrl=https%3A%2F%2Fservices.arcgisonline.com%2FArcGIS%2Frest%2Fservices%2FWorld_Imagery%2FMapServer`;

  return (
    <>
      <Button
        id="basic-button"
        aria-controls={open ? 'basic-menu' : undefined}
        aria-haspopup="true"
        aria-expanded={open ? 'true' : undefined}
        onClick={handleClick}
        sx={{ color: '#1d6ef0', fontSize: 13 }}
      >
        Open with...
      </Button>
      <Menu
        id="basic-menu"
        anchorEl={anchorEl}
        open={open}
        onClose={handleClose}
        MenuListProps={{
          'aria-labelledby': 'basic-button'
        }}
      >
        <MenuItem>
          <Link sx={{ color: '#1d6ef0' }} underline="hover" href={gMap} target="_blank">
            Google Map
          </Link>
        </MenuItem>
        <MenuItem>
          <Link sx={{ color: '#1d6ef0' }} underline="hover" href={bMap} target="_blank">
            Bing Map
          </Link>
        </MenuItem>
        <MenuItem>
          <Link sx={{ color: '#1d6ef0' }} underline="hover" href={esriMap} target="_blank">
            Esri Map
          </Link>
        </MenuItem>
        {/* <MenuItem>
          <Link
            sx={{ color: '#1d6ef0' }}
            underline="hover"
            href="https://www.planet.com/"
            target="_blank"
          >
            Planet.com
          </Link>
        </MenuItem> */}
      </Menu>
    </>
  );
}

BasicMenu.propTypes = {
  emitterProps: PropTypes.object
};
