import { useState } from 'react';
import { Box, Grid, Modal } from '@mui/material';

import styled from '@emotion/styled';
import CloseIcon from '@mui/icons-material/Close';
import FileCard from './FileCard';
import EditButton from './EditButton';
import InformationModal from 'ui-component/modals/TemporalProfileModal';
import FeedbackModal from 'ui-component/modals/FeedbackModal';
import IRFeedbackButton from './IRFeedbackButton';
import { useSelector } from 'store';
import { gridSpacing } from 'store/constant';

const ModalContent = styled(Box)`
  position: absolute;
  top: 50px;
  left: 100px;
  width: calc(100vw - 200px);
  height: calc(100vh - 100px);
  background: white;
`;

const CloseIconContainer = styled.div`
  position: absolute;
  top: 5px;
  right: 5px;
  cursor: pointer;
`;
const ContentContainer = styled.div`
  display: flex;
  justify-content: center;
  height: calc(100vh - 198px);
`;
const imageStyle = {
  height: '100%',
  maxWidth: '95%'
};
export default function Details() {
  const [modalOpen, setModalOpen] = useState(false);
  const [clusterProfile, setClusterProfile] = useState();
  const [open, setOpen] = useState(false);
  const handleClose = () => setOpen(false);
  const dashboardState = useSelector((state) => state.dashboard);
  const { selectedEmitterProps: emitterProps } = dashboardState;
  const { catalog_id: catalogId } = emitterProps;

  const clusterImageLink = `https://eogdata.mines.edu/wwwdata/hidden/VNF_multiyear_2012-2020/files/${catalogId?.replace(
    /source_\d/g,
    ''
  )}clusters.png`;
  const profileImageLink = `https://eogdata.mines.edu/wwwdata/hidden/VNF_multiyear_2012-2020/files/${catalogId}_profile.png`;

  const clusterImage = <img src={clusterImageLink} alt="Flare" style={imageStyle} />;
  const profileImage = <img src={profileImageLink} alt="Flare" style={imageStyle} />;

  if (!emitterProps) {
    return <></>;
  }

  return (
    <>
      <Grid container spacing={gridSpacing}>
        <Grid item xs={12}>
          <Grid item>
            <Grid container alignItems="center">
              <FileCard emitterProps={emitterProps} />
            </Grid>
            {catalogId && (
              <>
                <Grid
                  item
                  onClick={() => {
                    setClusterProfile('cluster');
                    setOpen(true);
                  }}
                  sx={{ cursor: 'pointer' }}
                >
                  <img src={clusterImageLink} alt="vnf multiyear" style={{ width: '100%' }} />
                </Grid>
                <Grid
                  item
                  onClick={() => {
                    setClusterProfile('profile');
                    setOpen(true);
                  }}
                  sx={{ cursor: 'pointer' }}
                >
                  <img src={profileImageLink} alt="vnf multiyear" style={{ width: '100%' }} />
                </Grid>
              </>
            )}
            <Grid item xs={12}>
              <Grid container spacing={1}>
                <Grid item xs={6}>
                  <InformationModal open={modalOpen} setOpen={setModalOpen} />
                </Grid>
                <Grid item xs={6}>
                  <FeedbackModal FeedbackButton={IRFeedbackButton} />
                </Grid>
                <Grid item xs={12}>
                  <EditButton />
                </Grid>
              </Grid>
            </Grid>
          </Grid>
        </Grid>
      </Grid>
      <Modal open={open} onClose={handleClose}>
        <ModalContent>
          <CloseIconContainer onClick={handleClose}>
            <CloseIcon />
          </CloseIconContainer>
          <ContentContainer>
            {clusterProfile === 'profile' ? profileImage : clusterImage}
          </ContentContainer>
        </ModalContent>
      </Modal>
    </>
  );
}
