import { dispatch, useSelector } from 'store';
import { setTemperature } from 'store/slices/filters';
import RangeSliderFilter from './RangeSliderFilter';
import { temperatureLimits } from 'config/filters/rangeFilters.json';

export default function AvgTempFilter() {
  const filterState = useSelector((state) => state.filters);
  const { temperature } = filterState;
  const { min, max } = temperatureLimits;
  const label = 'Average Temperature';
  const valueText = (value) => `${value} K`;

  const marks = [
    {
      value: 400,
      label: '400'
    },
    {
      value: 780,
      label: '780'
    },
    {
      value: 1160,
      label: '1160'
    },
    {
      value: 1540,
      label: '1540'
    },
    {
      value: 1920,
      label: '1920'
    },
    {
      value: 2300,
      label: '2300'
    }
  ];

  const handleChange = (e, newValue) => dispatch(setTemperature(newValue));

  return (
    <RangeSliderFilter
      value={temperature}
      label={label}
      valueText={valueText}
      handleChange={handleChange}
      marks={marks}
      min={min}
      max={max}
    />
  );
}
