import RangeSliderFilter from './RangeSliderFilter';
import { setMethaneEq } from 'store/slices/filters';
import { methaneEqScaleFn } from 'utils/filterUtils';
import { dispatch, useSelector } from 'store';
import { methaneEqLimits } from 'config/filters/rangeFilters.json';

export default function MethaneEqFilter() {
  const filterState = useSelector((state) => state.filters);
  const { methaneEq } = filterState;
  const { min, max, step } = methaneEqLimits;
  const label = 'Flared Gas';

  // values are scaled by 1000 to change units from bcm to mcm
  const marks = [
    {
      value: 0,
      label: '0'
    },
    {
      value: 2.2,
      label: `${parseFloat(methaneEqScaleFn(2.2) * 1000).toFixed(2)}`
    },
    {
      value: 4.4,
      label: `${parseFloat(methaneEqScaleFn(4.4) * 1000).toFixed(2)}`
    },
    {
      value: 6.6,
      label: `${parseFloat(methaneEqScaleFn(6.6) * 1000).toFixed(2)}`
    },
    {
      value: 8.8,
      label: `${parseFloat(methaneEqScaleFn(8.8) * 1000).toFixed(2)}`
    },
    {
      value: 11,
      label: `${parseFloat(methaneEqScaleFn(11) * 1000).toFixed(2)}`
    }
  ];

  const handleChange = (e, newValue) => {
    dispatch(setMethaneEq(newValue));
  };

  const valueText = (x) => (x * 1000).toFixed(2);

  return (
    <RangeSliderFilter
      value={methaneEq}
      label={label}
      valueLabelFormat={valueText}
      handleChange={handleChange}
      marks={marks}
      min={min}
      max={max}
      step={step}
      scale={methaneEqScaleFn}
      valueLabelDisplay="auto"
    />
  );
}
