import { dispatch, useSelector } from 'store';
import { setRadiantHeat } from 'store/slices/filters';
import { radiantHeatScaleFn } from 'utils/filterUtils';
import RangeSliderFilter from './RangeSliderFilter';
import { radiantHeatLimits } from 'config/filters/rangeFilters.json';

export default function RadiantHeatFilter() {
  const filterState = useSelector((state) => state.filters);
  const { radiantHeat } = filterState;
  const { min, max, step } = radiantHeatLimits;
  const label = 'Radiant Heat';

  const marks = [
    {
      value: 0,
      label: '0 MW'
    },
    {
      value: 3.4,
      label: `${parseFloat(radiantHeatScaleFn(3.4)).toFixed(3)}`
    },
    {
      value: 6.8,
      label: `${parseFloat(radiantHeatScaleFn(6.8)).toFixed(3)}`
    },
    {
      value: 10.2,
      label: `${parseFloat(radiantHeatScaleFn(10.2)).toFixed(2)}`
    },
    {
      value: 13.6,
      label: `${parseFloat(radiantHeatScaleFn(13.6)).toFixed(2)}`
    },
    {
      value: 17,
      label: `${parseFloat(radiantHeatScaleFn(17)).toFixed(2)}`
    }
  ];

  const handleChange = (e, newValue) => dispatch(setRadiantHeat(newValue));

  const valueText = (x) => `${parseFloat(radiantHeatScaleFn(x)).toFixed(4)}`;

  return (
    <RangeSliderFilter
      value={radiantHeat}
      label={label}
      valueLabelFormat={valueText}
      handleChange={handleChange}
      marks={marks}
      min={min}
      max={max}
      step={step}
    />
  );
}
