import { Box, Button, Grid, Stack, Typography } from '@mui/material';

import TypeFilters from './TypeFilters';
import AvgTempFilter from './AvgTempFilter';
import CountriesFilter from './CountriesFilter';
// import CategoryFilters from './CategoryFilters';
import MethaneEqFilter from './MethaneEqFilter';
import RadiantHeatFilter from './RadiantHeatFilter';
import DetectionFreqFilter from './DetectionFreqFilter';
import { clearAll } from 'store/slices/filters';
import { viirsMultiYearLayer } from 'config/layers/index';
import { useSelector, dispatch } from 'store';

export default function Filters() {
  const mapState = useSelector((state) => state.map);
  const layersState = useSelector((state) => state.layers);
  const { map } = mapState;
  const { layers } = layersState;

  const handleClearAll = () => {
    dispatch(clearAll());
    layers.forEach((layer) => {
      if (map.getLayer(layer.id)) {
        map.setFilter(layer.id, null);
      }
    });
  };

  return (
    <Grid item xs={12}>
      <Stack spacing={3}>
        {!layers[layers.findIndex((layer) => layer.id === viirsMultiYearLayer.id)].enabled && (
          <CountriesFilter />
        )}
        <Box>
          <Typography variant="h4">Types</Typography>
          <TypeFilters />
        </Box>
        {/* {layers[layers.findIndex((layer) => layer.id === viirsMultiYearLayer.id)].enabled && (
          <Box>
            <Typography variant="h4">Categories</Typography>
            <CategoryFilters />
          </Box>
        )} */}
        <Box>
          <Typography variant="h4">Average Temperature (K)</Typography>
          <AvgTempFilter />
        </Box>
        {!layers[layers.findIndex((layer) => layer.id === viirsMultiYearLayer.id)].enabled && (
          <>
            <Box>
              <Typography variant="h4">Radiant Heat (MW)</Typography>
              <RadiantHeatFilter />
            </Box>
            <Box>
              <Typography variant="h4">Flared Gas. (mcm/yr)</Typography>
              <MethaneEqFilter />
            </Box>
            <Box>
              <Typography variant="h4">Detection Frequency</Typography>
              <DetectionFreqFilter />
            </Box>
          </>
        )}
        <Button variant="contained" onClick={handleClearAll}>
          Clear All
        </Button>
      </Stack>
    </Grid>
  );
}
