import PropTypes from 'prop-types';
import { useTheme } from '@mui/styles';
import { Divider, Grid, Typography, Tooltip, IconButton, Box } from '@mui/material';

import {
  IconLayoutSidebarRightExpand,
  IconLayoutSidebarLeftExpand,
  IconArrowLeft
} from '@tabler/icons';

import Edit from './Edit';
import Stats from './Overview';
import Filters from './Filters';
import Details from './Details';
import { gridSpacing } from 'store/constant';
import { dotPointLayerConfig } from 'config/layers/pulseLayer';
import { useSelector, dispatch } from 'store';
import { ContextEnum, setCurrentContext, setSelectedEmitterProps } from 'store/slices/dashboard';
import { removeDetectionsLayerIf, removePulseLayerIf } from 'utils/layerUtils';

export default function InfoColumn({ showInfoColumn, handleShowInfoColumn }) {
  const theme = useTheme();
  const dashboardState = useSelector((state) => state.dashboard);
  const mapState = useSelector((state) => state.map);

  const showBackArrow = () => {
    switch (dashboardState.currentContext) {
      case ContextEnum.Overview:
        return false;
      case ContextEnum.Edit:
        return false;
      case ContextEnum.Filter:
        return true;
      case ContextEnum.Details:
        return true;
      default:
        return false;
    }
  };

  const showHideStyle = {
    // opacity: showInfoColumn ? '1' : '0',
    display: showInfoColumn ? 'block' : 'none',
    transition: 'all 0.5s'
  };

  const ContextComponent = () => {
    if (showInfoColumn) {
      switch (dashboardState.currentContext) {
        case ContextEnum.Overview:
          return <Stats />;
        case ContextEnum.Edit:
          return <Edit />;
        case ContextEnum.Filter:
          return <Filters />;
        case ContextEnum.Details:
          return <Details />;
        default:
          return <Stats />;
      }
    }
    return <></>;
  };

  const backArrowStyle = {
    cursor: 'pointer',
    color: theme.palette.primary.main,
    display: 'block'
  };

  const hiddenStyle = {
    display: 'none'
  };

  const handleClickBackArrow = () => {
    dispatch(setCurrentContext(ContextEnum.Overview));
    dotPointLayerConfig.lastPulseId = undefined;
    dispatch(setSelectedEmitterProps(null));
    removePulseLayerIf(mapState.map);
    removeDetectionsLayerIf(mapState.map);
  };

  return (
    <Grid container spacing={gridSpacing}>
      <Grid item xs={12}>
        <Grid container alignContent="center" justifyContent="space-between">
          <Grid item>
            <div style={{ marginLeft: showInfoColumn ? '0px' : '-5px' }}>
              <Tooltip title="Toggle the Statistics and Details Information">
                <IconButton sx={{ zIndex: '1' }} onClick={handleShowInfoColumn}>
                  {showInfoColumn ? (
                    <IconLayoutSidebarLeftExpand />
                  ) : (
                    <IconLayoutSidebarRightExpand />
                  )}
                </IconButton>
              </Tooltip>
            </div>
          </Grid>
          <Grid item sx={{ padding: '10px' }} style={showHideStyle}>
            <Typography variant="h3">
              {dashboardState.currentContext === ContextEnum.Details
                ? `${ContextEnum.Details} for IR Emitter #${dashboardState.selectedEmitterProps?.id}`
                : dashboardState.currentContext}
            </Typography>
          </Grid>
          <Grid item sx={{ flexGrow: 1 }} />
          {showInfoColumn && (
            <Grid item style={showBackArrow() ? backArrowStyle : hiddenStyle}>
              <IconArrowLeft onClick={handleClickBackArrow} />
            </Grid>
          )}
        </Grid>
        <Divider />
      </Grid>
      <Grid item xs={12} style={showHideStyle}>
        <Box style={{ height: 'calc(100vh - 225px)', overflow: 'auto' }}>
          <ContextComponent />
        </Box>
      </Grid>
    </Grid>
  );
}

InfoColumn.propTypes = {
  showInfoColumn: PropTypes.bool,
  handleShowInfoColumn: PropTypes.func
};
