import { useEffect, useState } from 'react';

import { Box, Grid } from '@mui/material';
import { useSearchParams } from 'react-router-dom';

import InfoColumn from './InfoColumn';
import MapComponent from './MapComponent';
import { dispatch, useSelector } from 'store/index';
import { setQueryFilters } from 'store/slices/filters';

import './dashboard.css';

export default function Dashboard() {
  const [showInfoColumn, setShowInfoColumn] = useState(true);
  const mapState = useSelector((state) => state.map);
  const { map } = mapState;

  const [search] = useSearchParams();
  useEffect(() => {
    const queryFilter = {};
    if (search.get('category')) {
      queryFilter.category = search.get('category').split(',');
    }
    if (search.get('country')) {
      queryFilter.country = search.get('country');
    }
    if (search.get('detectFreq')) {
      const detectFreq = search.get('detectFreq').split(',');
      if (detectFreq.length === 2) {
        queryFilter.detectFreq = { min: detectFreq[0], max: detectFreq[1] };
      }
    }
    if (search.get('methaneEq')) {
      const methaneEq = search.get('methaneEq').split(',');
      if (methaneEq.length === 2) {
        queryFilter.methaneEq = { min: methaneEq[0], max: methaneEq[1] };
      }
    }
    if (search.get('radiantHeat')) {
      const radiantHeat = search.get('radiantHeat').split(',');
      if (radiantHeat.length === 2) {
        queryFilter.methaneEq = { min: radiantHeat[0] * 1, max: radiantHeat[1] * 1 };
      }
    }
    if (search.get('temperature')) {
      const temp = search.get('temperature').split(',');
      if (temp.length === 2) {
        queryFilter.temperature = { min: temp[0] * 1, max: temp[1] * 1 };
      }
    }
    if (search.get('type')) {
      queryFilter.type = search.get('type').split(',');
    }
    if (queryFilter !== {}) {
      dispatch(setQueryFilters(queryFilter));
    }
  }, [search]);

  const handleShowInfoColumn = () => {
    setShowInfoColumn(!showInfoColumn);
    let count = 0;
    while (count < 1250) {
      setTimeout(() => map?.resize(), count);
      count += 1;
    }
  };
  const leftColumnStyle = {
    height: 'calc(100vh - 130px)',
    border: '1px solid lightgrey',
    borderRadius: '8px',
    minHeight: '600px',
    overflowY: 'auto'
  };

  const rightColumnStyle = {
    ...leftColumnStyle,
    padding: '8px',
    background: 'white',
    overflow: showInfoColumn ? 'auto' : 'hidden',
    animation: showInfoColumn ? 'showScroll 1s both' : ''
  };

  const infoColumnGridStyle = {
    flexBasis: showInfoColumn ? '' : '55px !important',
    maxWidth: showInfoColumn ? '' : '55px !important',
    transition: 'all 1s'
  };

  return (
    <Grid container spacing={1}>
      <Grid item xs>
        <Box sx={leftColumnStyle}>
          <MapComponent />
        </Box>
      </Grid>
      <Grid item xs={4} sx={infoColumnGridStyle}>
        <Box sx={rightColumnStyle} className="info-panel">
          <InfoColumn showInfoColumn={showInfoColumn} handleShowInfoColumn={handleShowInfoColumn} />
        </Box>
      </Grid>
    </Grid>
  );
}
