import { Grid } from '@mui/material';

import MainCard from 'ui-component/cards/MainCard';
import LayerComponent from './LayerComponent';
import isAuthorized from 'utils/auth';
import { useSelector } from 'store';
import RestrictedAccess from 'ui-component/RestrictedAccess';

const Layers = () => {
  const layerState = useSelector((state) => state.layers);
  const userState = useSelector((state) => state.user);

  return (
    <MainCard title="Map Layers">
      <Grid container spacing={3}>
        <Grid item xs={6}>
          <Grid container direction="column" spacing={3}>
            {layerState.layers.map((layer) => {
              const { id, name, description, enabled, requiredAuthLevel, tooltipText, config } =
                layer;
              const locked = !isAuthorized(userState, requiredAuthLevel);
              return (
                <LayerComponent
                  layerId={id}
                  name={name}
                  labelText={description}
                  enabled={enabled}
                  locked={locked}
                  tooltipText={tooltipText}
                  key={`layer-component-${id}`}
                  tileSource={config.tileSource}
                />
              );
            })}
          </Grid>
        </Grid>
        <Grid item xs={6}>
          <RestrictedAccess />
        </Grid>
      </Grid>
    </MainCard>
  );
};

export default Layers;
